cd /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/

clear
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using 1_nyt_ftpg_raw.log, replace 

************************************************************************************************************************
*  	Created By:		Boydstun                                                                                               	
*  	Creation Date:  11 May 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																								
*  	Directory:      /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/       	       														
*  	Do-file-name:   1_nyt_ftpg_raw.do 		                                                                    	    
*  	Purpose:        Read in and clean NYT front-page data                                                                            	
*                   Add date variables and time set them
*  	Data Input:     nyt_front_page_1996_2006.csv							                                      	
*  	Log File:       1_nyt_ftpg_raw.log    	                                                                          	
*  	Data Output:    1_nyt_ftpg_raw.dta											                                      	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:          Input dataset created by pasting data from Access (nyt_ftpg_1996_2006.mdb) into Excel (nyt_ftpg_1996_no_text.csv)        	
*					Steps in saving data from Access to CSV:
*						- Delete text and notes fields and extraneous variables (e.g., AccessID, section, author, etc.)
*						- Reformat date in 1/1/1996 format
*						- Replace TRUE with 1 and FALSE with 0
*						- Format all values as numbers
*
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly 
*					Questions: aboydstun@gmail.com      	
************************************************************************************************************************

*data source*
insheet using nyt_ftpg_1996_2006.csv, clear


***********************************************
***			GENERATE DATE VARIABLES			***
***********************************************
rename date datestring
generate day = daily(datestring, "MDY")
format day %td
gen month = mofd(day)
format month %tm
gen week = wofd(day)
format week %tw
gen quarter = qofd(day)
format quarter %tq
gen year = yofd(day)
format year %ty
drop datestring


***********************************************
***		CREATE TOTAL N VARIABLE		***
***********************************************
gen totaln = 1


***********************************************
***		CREATE DAILY STORIES VARIABLE		***
***********************************************
**variable: generate count of the number of stories per day**
sort day
by day: egen daily_stories = count(totaln)


***********************************************
***			ORGANIZE VARIABLE ORDER			***
***********************************************
order article_id day month week quarter year daily_stories topic_6digit topic_4digit topic_2digit waronterror katrina israelpalestine immigration presidentialelections clintonimpeachment enron darfur raceethnicity title summary 


***********************************************
***				SAVE DATA					***
***********************************************
save 1_nyt_ftpg_raw.dta, replace


***********************************************
***				CHECK DATA					***
***********************************************
tab topic_2digit, mi
tab topic_4digit, mi
tab topic_6digit, mi

tab daily_stories
sum daily_stories

tab day daily_stories if daily_stories ==4
tab day daily_stories if daily_stories ==11

