cd /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/analysis/

clear
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using 2A_other_agendas_topic_distributions.log, replace 

************************************************************************************************************************
*  	Created By:		Boydstun                                                                                               	
*  	Creation Date:  11 May 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																								
*  	Directory:      /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/       	       														
*  	Do-file-name:   2A_other_agendas_topic_distributions.do 		                                                                    	    
*  	Purpose:        Compare topic distributions across agendas
*					Run values for:
*						Figure 4.5
*						Figure 4.6                                                         	    
*  	Data Input:     PAP_NYT_1946_2005.csv
*					Executive_Orders_1945_2003.csv						                                      	
*					State_of_the_Union_Speeches_1946_2005.cs
*					Supreme_Court_Cases_1944_2006.csv
*					Congressional_Quarterly_Almanac_1947_2008.csv
*					Congressional_Hearings_1946_2008.csv
*					Public_Laws_1948_2007.csv
*					Roll_Call_Votes_1946_2004.dta
*					Bills_104_to_109_1995_2006.dta
*					mip_1945_2007_monthly_imputed.dta
*  	Log File:       2A_other_agendas_topic_distributions.log    	                                                                          	
*  	Data Output:   											                                      	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:          Topic numbers based on Policy Agendas Topics Codebook with Media Coding Addendums
*    	            											 												      	
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly 
*					Questions: aboydstun@gmail.com      	
************************************************************************************************************************

***********************************
* Input data and organize dataset *
***********************************

* PAP NYT Full Paper data ()
insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_NYT_data/PAP_NYT_1946_2005.csv

* PAP Executive Order data (19 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_President_data/Executive_Orders_1945_2003.csv

* PAP State of the Union data (19 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_President_data/State_of_the_Union_Speeches_1946_2005.csv

* PAP Supreme Court Cases data (20 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Supreme_Court_data/Supreme_Court_Cases_1944_2006.csv

* PAP Congressional Quarterly Almanac data (19 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Congressional_Quarterly_Almanac_1947_2008.csv

* PAP Congressional Hearings data (19 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Hearings_data/Congressional_Hearings_1946_2008.csv

* PAP Congressional Public Laws data (20 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Public_Laws_1948_2007.csv

* PAP Congressional Roll Call Votes data (20 topic categories)
*use /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Roll_Call_data/Roll_Call_Votes_1946_2004.dta, replace

* Congressional Bills Project data (20 topic categories)
*use /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Bills_data/Bills_104_to_109_1995_2006.dta, replace
*rename major majortopic

* If using the MIP data, un-comment the delimit command below
*#delimit ;
*
drop if year<1996
drop if year>2006
rename majortopic topic
gen totaln=1


***********************************************
***				FIGURE 4.5					***
***				FIGURE 4.6					***
***********************************************
* Collapse by topic
collapse (sum) totaln, by(topic)
list
***********************************************


* Generate proportions
egen _freq=total(totaln)

*list

* If using the MIP data, un-comment the delimiter below 
*;
#delimit cr



***********************************************
***			MIP FOR FIGURE 4.5				***
***********************************************

***********************
* Use this section for:
* MIP data
* by commenting out the #delimit command below
***********************

#delimit ;

* PAP MIP data (20 topic categories)
use /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_MIP_data/mip_1945_2007_monthly_imputed.dta, replace
drop if year<1996
drop if year>2006
foreach var of varlist imp_* {
	egen total`var' = total(`var')
	}
keep totalimp_*
keep if _n==1
egen _freq=rowtotal(totalimp_*)
foreach var of varlist totalimp_* {
	gen v`var' = `var'/_freq
	}
keep v*

;
