cd /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/

clear
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using 2_nyt_ftpg_topics.log, replace 

************************************************************************************************************************
*  	Created By:		Boydstun                                                                                               	
*  	Creation Date:  11 May 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																								
*  	Directory:      /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/										
*  	Do-file-name:   2_nyt_ftpg_topics.do 		                                                                    	    
*  	Purpose:        
*					Generate dummy variables for domestic policy and domestic topic codes
*					Generate dummy variable for each 2-digit topic category
*					Generate dummy variable for each 4-digit subtopic category
*					Recode foreign issues by major topic to compare coding
*					Run values for: 
*						Human rights story count in Chapter 2
*						Figure 4.3a-b
*						Figure 4.4                                                      	    
*						Figure 4.6                                                      	    
*						Table A.1
*						Figure A.1
*						Figure A.2
*  	Data Input:     1_nyt_ftpg_raw.dta								                                      	
*  	Log File:       2_nyt_ftpg_topics.log    	                                                                          	
*  	Data Output:    2_nyt_ftpg_topics.dta											                                      	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:          Topic numbers based on Policy Agendas Topics Codebook with Media Coding Addendums
*    	            											 												      	
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly 
*					Questions: aboydstun@gmail.com      	
************************************************************************************************************************

*data source*
use 1_nyt_ftpg_raw.dta, replace


***********************************************
***		CREATE DOMESTIC/FOREIGN VARIABLES	***
***********************************************
gen domestic_topics = 1
replace domestic_topics = 0 if topic_2digit ==16 | topic_2digit ==18 | topic_2digit ==19 | topic_2digit ==23 | topic_2digit ==24 | topic_2digit ==26 | topic_2digit ==27 | topic_2digit ==29 | topic_2digit ==30 | topic_2digit ==31 | topic_2digit ==99  

gen foreign_topics = 0
replace foreign_topics = 1 if topic_2digit ==16 | topic_2digit ==18 | topic_2digit ==19 


***********************************************
***		CREATE 2-DIGIT TOPIC DUMMY VARS		***
***********************************************
foreach i of numlist 1 2 3 4 5 6 7 8 10 12 13 14 15 16 17 18 19 20 21 24 26 27 28 29 30 31 99 {
        gen majortopic`i'=0
        replace majortopic`i'=1 if topic_2digit==`i'
        }


***********************************************
***	  CREATE 4-DIGIT SUB-TOPIC DUMMY VARS	***
***********************************************
foreach i of numlist 100 101 103 104 105 107 108 110 199 200 201 202 204 205 206 207 208 209 299 300 301 302 321 322 323 324 325 331 332 333 334 335 336 341 342 343 344 398 399 400 401 402 403 404 405 498 499 500 501 502 503 504 505 506 508 529 530 599 600 601 602 603 604 606 607 609 698 699 700 701 703 704 705 707 708 709 710 711 798 799 800 801 802 803 805 806 807 898 899 1000 1001 1002 1003 1005 1006 1007 1010 1098 1099 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1299 1300 1301 1302 1303 1304 1305 1399 1400 1401 1403 1404 1405 1406 1407 1408 1409 1410 1499 1500 1501 1502 1504 1505 1507 1520 1521 1522 1523 1524 1525 1526 1599 1600 1602 1603 1604 1605 1606 1608 1609 1610 1611 1612 1614 1615 1616 1617 1619 1620 1698 1699 1700 1701 1704 1705 1706 1707 1708 1709 1798 1799 1800 1802 1803 1804 1806 1807 1808 1899 1900 1901 1902 1905 1906 1907 1908 1909 1910 1911 1912 1914 1915 1919 1920 1921 1925 1926 1927 1929 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2030 2099 2100 2101 2102 2103 2104 2105 2199 2400 2600 2700 2800 2900 3000 3100 9900 {
        gen subtopic`i'=0
        replace subtopic`i'=1 if topic_4digit==`i'
        }


***********************************************
***	  RECODE FOREIGN ISSUES BY MAJOR TOPIC	***
***********************************************
*To recode in this way, comment out the #delimit line below:
#delimit ;
*
recode topic_2digit (19 = 01) if topic_6digit == 190001 | topic_6digit == 190701 | topic_6digit == 190801 | topic_6digit == 190901 | topic_6digit == 191001 | topic_6digit == 191101 | topic_6digit == 191201 | topic_6digit == 191401 | topic_6digit == 191501 | topic_6digit == 191901 | topic_6digit == 192001 | topic_6digit == 192101
recode topic_2digit (19 = 02) if topic_6digit == 190002 | topic_6digit == 190702 | topic_6digit == 190802 | topic_6digit == 190902 | topic_6digit == 191002 | topic_6digit == 191102 | topic_6digit == 191202 | topic_6digit == 191402 | topic_6digit == 191502 | topic_6digit == 191902 | topic_6digit == 192002 | topic_6digit == 192102
recode topic_2digit (19 = 03) if topic_6digit == 190003 | topic_6digit == 190703 | topic_6digit == 190803 | topic_6digit == 190903 | topic_6digit == 191003 | topic_6digit == 191103 | topic_6digit == 191203 | topic_6digit == 191403 | topic_6digit == 191503 | topic_6digit == 191903 | topic_6digit == 192003 | topic_6digit == 192103
recode topic_2digit (19 = 04) if topic_6digit == 190004 | topic_6digit == 190704 | topic_6digit == 190804 | topic_6digit == 190904 | topic_6digit == 191004 | topic_6digit == 191104 | topic_6digit == 191204 | topic_6digit == 191404 | topic_6digit == 191504 | topic_6digit == 191904 | topic_6digit == 192004 | topic_6digit == 192104
recode topic_2digit (19 = 05) if topic_6digit == 190005 | topic_6digit == 190705 | topic_6digit == 190805 | topic_6digit == 190905 | topic_6digit == 191005 | topic_6digit == 191105 | topic_6digit == 191205 | topic_6digit == 191405 | topic_6digit == 191505 | topic_6digit == 191905 | topic_6digit == 192005 | topic_6digit == 192105
recode topic_2digit (19 = 06) if topic_6digit == 190006 | topic_6digit == 190706 | topic_6digit == 190806 | topic_6digit == 190906 | topic_6digit == 191006 | topic_6digit == 191106 | topic_6digit == 191206 | topic_6digit == 191406 | topic_6digit == 191506 | topic_6digit == 191906 | topic_6digit == 192006 | topic_6digit == 192106
recode topic_2digit (19 = 07) if topic_6digit == 190007 | topic_6digit == 190707 | topic_6digit == 190807 | topic_6digit == 190907 | topic_6digit == 191007 | topic_6digit == 191107 | topic_6digit == 191207 | topic_6digit == 191407 | topic_6digit == 191507 | topic_6digit == 191907 | topic_6digit == 192007 | topic_6digit == 192107
recode topic_2digit (19 = 08) if topic_6digit == 190008 | topic_6digit == 190708 | topic_6digit == 190808 | topic_6digit == 190908 | topic_6digit == 191008 | topic_6digit == 191108 | topic_6digit == 191208 | topic_6digit == 191408 | topic_6digit == 191508 | topic_6digit == 191908 | topic_6digit == 192008 | topic_6digit == 192108
recode topic_2digit (19 = 10) if topic_6digit == 190010 | topic_6digit == 190710 | topic_6digit == 190810 | topic_6digit == 190910 | topic_6digit == 191010 | topic_6digit == 191110 | topic_6digit == 191210 | topic_6digit == 191410 | topic_6digit == 191510 | topic_6digit == 191910 | topic_6digit == 192010 | topic_6digit == 192110
recode topic_2digit (19 = 12) if topic_6digit == 190012 | topic_6digit == 190712 | topic_6digit == 190812 | topic_6digit == 190912 | topic_6digit == 191012 | topic_6digit == 191112 | topic_6digit == 191212 | topic_6digit == 191412 | topic_6digit == 191512 | topic_6digit == 191912 | topic_6digit == 192012 | topic_6digit == 192112
recode topic_2digit (19 = 13) if topic_6digit == 190013 | topic_6digit == 190713 | topic_6digit == 190813 | topic_6digit == 190913 | topic_6digit == 191013 | topic_6digit == 191113 | topic_6digit == 191213 | topic_6digit == 191413 | topic_6digit == 191513 | topic_6digit == 191913 | topic_6digit == 192013 | topic_6digit == 192113
recode topic_2digit (19 = 14) if topic_6digit == 190014 | topic_6digit == 190714 | topic_6digit == 190814 | topic_6digit == 190914 | topic_6digit == 191014 | topic_6digit == 191114 | topic_6digit == 191214 | topic_6digit == 191414 | topic_6digit == 191514 | topic_6digit == 191914 | topic_6digit == 192014 | topic_6digit == 192114
recode topic_2digit (19 = 15) if topic_6digit == 190015 | topic_6digit == 190715 | topic_6digit == 190815 | topic_6digit == 190915 | topic_6digit == 191015 | topic_6digit == 191115 | topic_6digit == 191215 | topic_6digit == 191415 | topic_6digit == 191515 | topic_6digit == 191915 | topic_6digit == 192015 | topic_6digit == 192115
recode topic_2digit (19 = 16) if topic_6digit == 190016 | topic_6digit == 190716 | topic_6digit == 190816 | topic_6digit == 190916 | topic_6digit == 191016 | topic_6digit == 191116 | topic_6digit == 191216 | topic_6digit == 191416 | topic_6digit == 191516 | topic_6digit == 191916 | topic_6digit == 192016 | topic_6digit == 192116
recode topic_2digit (19 = 17) if topic_6digit == 190017 | topic_6digit == 190717 | topic_6digit == 190817 | topic_6digit == 190917 | topic_6digit == 191017 | topic_6digit == 191117 | topic_6digit == 191217 | topic_6digit == 191417 | topic_6digit == 191517 | topic_6digit == 191917 | topic_6digit == 192017 | topic_6digit == 192117
recode topic_2digit (19 = 18) if topic_6digit == 190018 | topic_6digit == 190718 | topic_6digit == 190818 | topic_6digit == 190918 | topic_6digit == 191018 | topic_6digit == 191118 | topic_6digit == 191218 | topic_6digit == 191418 | topic_6digit == 191518 | topic_6digit == 191918 | topic_6digit == 192018 | topic_6digit == 192118
recode topic_2digit (19 = 19) if topic_6digit == 190019 | topic_6digit == 190719 | topic_6digit == 190819 | topic_6digit == 190919 | topic_6digit == 191019 | topic_6digit == 191119 | topic_6digit == 191219 | topic_6digit == 191419 | topic_6digit == 191519 | topic_6digit == 191919 | topic_6digit == 192019 | topic_6digit == 192119
recode topic_2digit (19 = 20) if topic_6digit == 190020 | topic_6digit == 190720 | topic_6digit == 190820 | topic_6digit == 190920 | topic_6digit == 191020 | topic_6digit == 191120 | topic_6digit == 191220 | topic_6digit == 191420 | topic_6digit == 191520 | topic_6digit == 191920 | topic_6digit == 192020 | topic_6digit == 192120
recode topic_2digit (19 = 21) if topic_6digit == 190021 | topic_6digit == 190721 | topic_6digit == 190821 | topic_6digit == 190921 | topic_6digit == 191021 | topic_6digit == 191121 | topic_6digit == 191221 | topic_6digit == 191421 | topic_6digit == 191521 | topic_6digit == 191921 | topic_6digit == 192021 | topic_6digit == 192121
recode topic_2digit (19 = 24) if topic_6digit == 190024 | topic_6digit == 190724 | topic_6digit == 190824 | topic_6digit == 190924 | topic_6digit == 191024 | topic_6digit == 191124 | topic_6digit == 191224 | topic_6digit == 191424 | topic_6digit == 191524 | topic_6digit == 191924 | topic_6digit == 192024 | topic_6digit == 192124
recode topic_2digit (19 = 26) if topic_6digit == 190026 | topic_6digit == 190726 | topic_6digit == 190826 | topic_6digit == 190926 | topic_6digit == 191026 | topic_6digit == 191126 | topic_6digit == 191226 | topic_6digit == 191426 | topic_6digit == 191526 | topic_6digit == 191926 | topic_6digit == 192026 | topic_6digit == 192126
recode topic_2digit (19 = 27) if topic_6digit == 190027 | topic_6digit == 190727 | topic_6digit == 190827 | topic_6digit == 190927 | topic_6digit == 191027 | topic_6digit == 191127 | topic_6digit == 191227 | topic_6digit == 191427 | topic_6digit == 191527 | topic_6digit == 191927 | topic_6digit == 192027 | topic_6digit == 192127
recode topic_2digit (19 = 28) if topic_6digit == 190028 | topic_6digit == 190728 | topic_6digit == 190828 | topic_6digit == 190928 | topic_6digit == 191028 | topic_6digit == 191128 | topic_6digit == 191228 | topic_6digit == 191428 | topic_6digit == 191528 | topic_6digit == 191928 | topic_6digit == 192028 | topic_6digit == 192128
recode topic_2digit (19 = 29) if topic_6digit == 190029 | topic_6digit == 190729 | topic_6digit == 190829 | topic_6digit == 190929 | topic_6digit == 191029 | topic_6digit == 191129 | topic_6digit == 191229 | topic_6digit == 191429 | topic_6digit == 191529 | topic_6digit == 191929 | topic_6digit == 192029 | topic_6digit == 192129
recode topic_2digit (19 = 30) if topic_6digit == 190030 | topic_6digit == 190730 | topic_6digit == 190830 | topic_6digit == 190930 | topic_6digit == 191030 | topic_6digit == 191130 | topic_6digit == 191230 | topic_6digit == 191430 | topic_6digit == 191530 | topic_6digit == 191930 | topic_6digit == 192030 | topic_6digit == 192130
recode topic_2digit (19 = 31) if topic_6digit == 190031 | topic_6digit == 190731 | topic_6digit == 190831 | topic_6digit == 190931 | topic_6digit == 191031 | topic_6digit == 191131 | topic_6digit == 191231 | topic_6digit == 191431 | topic_6digit == 191531 | topic_6digit == 191931 | topic_6digit == 192031 | topic_6digit == 192131
recode topic_2digit (19 = 99) if topic_6digit == 190099 | topic_6digit == 190799 | topic_6digit == 190899 | topic_6digit == 190999 | topic_6digit == 191099 | topic_6digit == 191199 | topic_6digit == 191299 | topic_6digit == 191499 | topic_6digit == 191599 | topic_6digit == 191999 | topic_6digit == 192099 | topic_6digit == 192199
*;
#delimit cr        


***********************************************
***				SAVE DATA					***
***********************************************
save 2_nyt_ftpg_topics.dta, replace


***********************************************
***				CHECK DATA					***
***********************************************
tab topic_2digit
tab topic_4digit


***********************************************
***				TABLE A.1					***

***				FIGURE 4.3a-b				***

***			USE FOR FIGURE A.1 IF			*** 
***		TOPICS HAVE BEEN RECODED ABOVE		*** 
***********************************************
*collapse(sum) totaln, by(topic_2digit)
*list
*exit

***********************************************
***				FIGURE A.2					***
***********************************************
*Use only for Figure A.2, un-commenting one date range at a time
*BEFORE 9/11
*keep if day < 15230
*AFTER 9/11
*keep if day >= 15230
*collapse(sum) totaln, by(topic_2digit)
*list
***********************************************


***********************************************
***				FIGURE 4.4					***
***********************************************
* To work at the subtopic level
*collapse(sum) totaln, by(topic_4digit)
*list
*exit
***********************************************


***********************************************
***				FIGURE 4.6					***
***********************************************
* To limit to the 1996-2005 date range, comment out the Table A.1 and Figure A.1 commands above
*drop if year>2005
*collapse(sum) totaln, by(topic_2digit)
*list
***********************************************


***********************************************
***		Human rights count for Ch. 2		***
***********************************************
*sum topic_4digit if topic_4digit==1925
***********************************************

