cd /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/

clear
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using 3_nyt_ftpg_collapsed_by_time.log, replace

************************************************************************************************************************
*  	Created By:		AEB                                                                                              	
*  	Creation Date:  11 May 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																								
*  	Directory:      /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/       	       														
*  	Do-file-name:   3_nyt_ftpg_collapsed_by_time.do 		                                                                    	    
*  	Purpose:        Collapse by time and generate proportions                                                         	    
*  	Data Input:     2_nyt_ftpg_topics.dta								                                      	
*  	Log File:       3_nyt_ftpg_collapsed_by_time.log    	                                                                          	
*  	Data Output:    3_nyt_ftpg_collapsed_by_month.dta											                                      	
*  					3_nyt_ftpg_collapsed_by_quarter.dta	
*  					3_nyt_ftpg_collapsed_by_year.dta											                                      											                                      	
*					Run values for:
*						Figure 4.1
*						Figure 4.2
*						Figure 4.7
*						Figure 4.8                                                         	                                                             	    
*						Figure 4.9
*						Figure 4.10                                                         	                                                             	    
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:          Can be collapsed by alternate time units: day, month, week, quarter, year    	
*
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly 
*					Questions: aboydstun@gmail.com   
************************************************************************************************************************

*data source*
use 2_nyt_ftpg_topics.dta, replace


***********************************************
***		COLLAPSE VARIABLES BY TIME UNIT		***
***********************************************
* Change the temporal unit of analysis by replacing the by() command below with day, week, month, quarter, or year
#delimit ;
collapse(sum) totaln 
waronterror katrina israelpalestine immigration presidentialelections clintonimpeachment enron darfur raceethnicity 
majortopic* subtopic*
, by(month);
#delimit cr

sum totaln
*exit

***********************************************
***				FIGURE 4.1					***
***********************************************
* After collapsing by day above
tab totaln
sum totaln
*exit
***********************************************


***********************************************
***				FIGURE 4.2					***
***********************************************
* After collapsing by year above
*sort year
*keep year totaln
*sum totaln
*list

***********************************************


***********************************************
***				FIGURE 4.7					***
***				FIGURE 4.8					***
***				FIGURE 4.9					***
***********************************************
* After collapsing by time unit above;
*keep month totaln majortopic*
***********************************************


***********************************************
***				FIGURE 4.10					***
***********************************************
* After collapsing by month above;
*keep month totaln subtopic2012 subtopic2005 subtopic2900 subtopic2600 subtopic341 subtopic1615
***********************************************


***********************************************
***				TSSET TIME UNIT				***
***********************************************
* After collapsing by time unit above;
*tsset month
*tsset quarter
*tsset year


***********************************************



***********************************************
***		GENERATE PROPORTION VARIABLES		***
***********************************************
gen prop_waronterror = waronterror/totaln
gen prop_katrina = katrina/totaln
gen prop_israelpalestine = israelpalestine/totaln
gen prop_immigration = immigration/totaln
gen prop_presidentialelections = presidentialelections/totaln
gen prop_clintonimpeachment = clintonimpeachment/totaln
gen prop_enron = enron/totaln
gen prop_darfur = darfur/totaln
gen prop_raceethnicity = raceethnicity/totaln

foreach i of varlist majortopic* {
	gen prop_`i' = `i'/totaln
}

foreach i of varlist subtopic* {
	gen prop_`i' = `i'/totaln
}


***********************************************
***				SAVE DATA					***
***********************************************
save 3_nyt_ftpg_collapsed_by_week.dta, replace
*save 3_nyt_ftpg_collapsed_by_month.dta, replace
*save 3_nyt_ftpg_collapsed_by_quarter.dta, replace
*save 3_nyt_ftpg_collapsed_by_year.dta, replace


***********************************************
***				CHECK DATA					***
***********************************************
sum majortopic*

