cd /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/analysis/

clear
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using 4A_skew.log, replace

************************************************************************************************************************
*  	Created By:		AEB                                                                                              	
*  	Creation Date:  11 May 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																								
*  	Directory:      /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/       	       														
*  	Do-file-name:   4A_skew.do 		                                                                    	    
*  	Purpose:        Calculate skew across topics for NYT and other agendas                                                    	    
*					Run values for: 
*						Table 7.1
*  	Data Input:     2_nyt_ftpg_topics.dta								                                      	
*					PAP_NYT_1946_2005.csv
*					Executive_Orders_1945_2003.csv						                                      	
*					State_of_the_Union_Speeches_1946_2005.cs
*					Supreme_Court_Cases_1944_2006.csv
*					Congressional_Quarterly_Almanac_1947_2008.csv
*					Congressional_Hearings_1946_2008.csv
*					Public_Laws_1948_2007.csv
*					Roll_Call_Votes_1946_2004.dta
*					Bills_104_to_109_1995_2006.dta
*					mip_1945_2007_monthly_imputed.dta
*  	Log File:       4A_skew.log    	                                                                          	
*  	Data Output:    	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:               	
*
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly 
*					Questions: aboydstun@gmail.com   
************************************************************************************************************************

***********************************************
***			SKEW ACROSS TOPICS				***
***********************************************

***********************************
* Input data and organize dataset *
***********************************

***********************
* Use this section for everything EXCEPT the MIP data
***********************
* To calculate the skew of a dataset, un-comment its input command

*#delimit ;

* NYT front-page data (27 topic categories)
use 2_nyt_ftpg_topics.dta, replace
rename topic_2digit topic

* PAP NYT full-paper sample data (27 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_NYT_data/PAP_NYT_1946_2005.csv

* PAP Executive Order data (19 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_President_data/Executive_Orders_1945_2003.csv

* PAP State of the Union data (19 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_President_data/State_of_the_Union_Speeches_1946_2005.csv

* PAP Supreme Court Cases data (20 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Supreme_Court_data/Supreme_Court_Cases_1944_2006.csv

* PAP Congressional Quarterly Almanac data (19 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Congressional_Quarterly_Almanac_1947_2008.csv

* PAP Congressional Hearings data (19 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Congressional_Hearings_1946_2008.csv

* PAP Congressional Public Laws data (20 topic categories)
*insheet using /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Public_Laws_1948_2007.csv

* PAP Congressional Roll Call Votes data (20 topic categories)
*use /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Roll_Call_data/Roll_Call_Votes_1946_2004.dta, replace

* Congressional Bills Project data (20 topic categories)
*use /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Bills_data/Bills_104_to_109_1995_2006.dta, replace
*rename major majortopic

drop if year<1996
drop if year>2006
*rename majortopic topic
gen totaln=1

* Collapse by topic
collapse (sum) totaln, by(topic)
tab topic
*exit

* Generate proportions
egen _freq=total(totaln)
gen prop = totaln/_freq
replace prop = .000000000000000001 if prop ==0
drop totaln _freq

* Restructure data and reduce to single row
xpose, clear varname
rename _varname old_varname
drop if old_varname=="topic"
drop old_varname

*;
#delimit cr

***********************
* Use this section for:
* MIP data
* by commenting out the #delimit command below
***********************

#delimit ;

* PAP MIP data (20 topic categories)
use /Users/boydstun/dropbox/A/_PROJECTS/nyt/book/data/PAP_MIP_data/mip_1945_2007_monthly_imputed.dta, replace
drop if year<1996
drop if year>2006
foreach var of varlist imp_* {
	egen total`var' = total(`var')
	}
keep totalimp_*
keep if _n==1
egen _freq=rowtotal(totalimp_*)
foreach var of varlist totalimp_* {
	gen v`var' = `var'/_freq
	}
keep v*

* If using the MIP data, comment out the ; below
;
#delimit cr

***********************************
*   		TABLE 7.1  			  *
***********************************
* Calculate 4 measures of skew  
* CHANGE NUMBER OF TOPIC CATEGORIES ACCORDINGLY
* 1. HerfindahlHirschman Index
* 2. Normalized HerfindahlHirschman Index
* 3. Inverse Shannon's H Entropy
* 4. Inverse Normalized Shannon's H Entropy 
foreach var of varlist v* {
	gen squared`var' = `var'^2
	gen lnproduct`var' = `var'*ln(`var')
	}
egen herf = rowtotal(squared*)
*gen normherf = (herf-1/27)/(1-1/27)
*gen normherf = (herf-1/20)/(1-1/20)
gen normherf = (herf-1/19)/(1-1/19)
egen total_lnproduct = rowtotal(lnproduct*)
gen entropy = -(total_lnproduct)
*gen inventropy = ln(27) - entropy
*gen inventropy = ln(20) - entropy
gen inventropy = ln(19) - entropy
*gen normentropy = (entropy/ln(27))
*gen normentropy = (entropy/ln(20))
gen normentropy = (entropy/ln(19))
gen invnormentropy = 1 - normentropy
order invnormentropy normherf inventropy herf normentropy entropy 
