cd /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/

clear
clear matrix
clear mata
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using 4B_explosiveness.log, replace

************************************************************************************************************************
*  	Created By:		AEB                                                                                              	
*  	Creation Date:  11 May 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																								
*  	Directory:      /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/       	       														
*  	Do-file-name:   4B_explosiveness.do 		                                                                    	    
*  	Purpose:        Calculate explosiveness across topics for NYT and other agendas                                                     	    
*  	Data Input:     2_nyt_ftpg_topics.dta								                                      	
*  	Log File:       4B_explosiveness.log    	                                                                          	
*  	Data Output:    	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:               	
*
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly 
*					Questions: aboydstun@gmail.com   
************************************************************************************************************************

***********************************************
***		EXPLOSIVENESS ACROSS TOPICS			***
***********************************************

***********************************
* Input data and organize dataset *
***********************************

***********************
* Use this section for everything EXCEPT the MIP data
***********************
* To calculate the explosiveness of a dataset, un-comment its input command

*#delimit ;

* NYT front-page data (27 topic categories)
use 2_nyt_ftpg_topics.dta, replace
rename topic_2digit topic

* PAP NYT full-paper sample data (27 topic categories)
*insheet using /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_NYT_data/PAP_NYT_1946_2005.csv

* PAP Executive Order data (19 topic categories)
*insheet using /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_President_data/Executive_Orders_1945_2003.csv

* PAP State of the Union data (19 topic categories)
*insheet using /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_President_data/State_of_the_Union_Speeches_1946_2005.csv

* PAP Supreme Court Cases data (20 topic categories)
*insheet using /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_Supreme_Court_data/Supreme_Court_Cases_1944_2006.csv

* PAP Congressional Quarterly Almanac data (19 topic categories)
*insheet using /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Congressional_Quarterly_Almanac_1947_2008.csv

* PAP Congressional Hearings data (19 topic categories)
*insheet using /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Congressional_Hearings_1946_2008.csv

* PAP Congressional Public Laws data (20 topic categories)
*insheet using /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Public_Laws_1948_2007.csv

* PAP Congressional Roll Call Votes data (20 topic categories)
*use /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Roll_Call_data/Roll_Call_Votes_1946_2004.dta, replace

* Congressional Bills Project data (20 topic categories)
*use /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Bills_data/Bills_104_to_109_1995_2006.dta, replace
*rename major majortopic

***********************************************
***		CREATE TOPIC DUMMY VARS	AND MONTH	***
***********************************************
#delimit ;
*
rename majortopic topic
gen totaln=1
foreach i of numlist 1 2 3 4 5 6 7 8 10 12 13 14 15 16 17 18 19 20 21 24 26 27 28 29 30 31 99 {
        gen majortopic`i'=0
        replace majortopic`i'=1 if topic==`i'
        }

rename date datestring
generate day = daily(datestring, "MDY")
format day %td
gen month = mofd(day)
format month %tm
;

#delimit cr
***********************************************


drop if year<1996
drop if year>2006
*gen totaln=1

* Collapse by topic
collapse (sum) totaln majortopic*, by(month)
tsset month
*tab topic
*exit

foreach i of varlist majortopic* {
	gen prop_`i' = (`i'/totaln) * 100
	}
	
***********************************************************
***	  			GENERATE CHANGE VALUES					***
***********************************************************
foreach i of varlist majortopic* {
	gen D_`i' = D.`i'
	}

foreach i of varlist majortopic* {
	gen absD_`i' = abs(D.`i')
}	

***again for proportion values
foreach i of varlist prop_majortopic* {
	gen D_`i' = D.`i'
	}

foreach i of varlist prop_majortopic* {
	gen absD_`i' = abs(D.`i')
}	


*egen total_abs_change = rowtotal(absD_majortopic*)

sort month
tsset month

*******************************************
*** Drop first observation of no change ***
*******************************************
drop if _n==1

*******************************************
*** Drop all observations of no change ***
*******************************************
*drop if total_abs_change==0
recode D_*(0=.)

***********************************************
***			STACKING INTO CHANGE		***
***********************************************
*stack D_*, into(change)
stack D_prop*, into(change)

sort change

drop if change==.

***RUNNING L-MOMENTS AGAIN, THIS TIME ACROSS ALL VALUES WITHOUT AVERAGING
foreach i of varlist change {
	lmoments `i'
	gen Dskew_`i' = r(t_3)
 	gen Dkurtosis_`i' = r(t_4)
 	destring Dskew_`i', replace
 	destring Dkurtosis_`i', replace
 	summarize `i'
 	gen Dmean_`i' = r(mean)
 	gen Dsd_`i' = r(sd)
	gen Dmin_`i' = r(min)
 	gen Dmax_`i' = r(max) 
}

disp Dkurtosis

***********************************************
***			FIGURE 7.1 HISTORGRAM			***
***********************************************
#delimit ;
***(To use after converting into clean change data set)***;
*histogram var2, frequency fcolor("170 218 3") lcolor(black) normal normopts (lcolor("255 255 0") lwidth(thick) lpattern(solid)) ylabel(, tlcolor(black) labcolor(black)) xtitle(Issue Topics, color(black)) graphregion(fcolor(192 192 192) lcolor(none) ifcolor(192 192 192) ilcolor(none)) plotregion(fcolor(192 192 192) lcolor(none) ifcolor(192 192 192) ilcolor(none));


***Black Bars, White Background;
graph set window fontface "Helvetica";

histogram change, frequency fcolor(black) lcolor(black) normal normopts(lcolor(gray))
ytitle(Number of Cases) ylabel(, grid nogmax nogmin glcolor(white))
xtitle(Degree of Change in Real Stories)
graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white));

*exit;

graph export "HIST_change.eps", fontface("Heletica") replace;
exit;

#delimit cr

*first create a dataset of frequencies by the percentage change variable you want to graph
*contract change
contract change

*now separate out negatives and positives
gen neg = change
gen pos = change
recode neg(0/max=.)
recode pos(min/-0.000000001=.)

*change the negative freqs to positive so they can be graphed
gen neg2=neg*-1

*now calculate cumulative frequencies from these
cumul pos [fweight=_freq], gen(cumul_pos_nyt) freq equal
cumul neg2 [fweight=_freq], gen(cumul_neg_nyt) freq equal

*now we need the inverse cumulatives
egen posmax=max(cumul_pos_nyt)
gen maxcumposnyt=posmax+1
gen inv_cum_pos_nyt=maxcumposnyt-cumul_pos_nyt

egen negmax=max(cumul_neg_nyt)
gen maxcumnegnyt=negmax+1
gen inv_cum_neg_nyt=maxcumnegnyt-cumul_neg_nyt


*now look at the results
*hist prop_change, freq normal
*scatter  inv_cum_pos_nyt pos 
*scatter  inv_cum_pos_nyt pos, yscale(log)
*same as above but with better labels so it looks better
*scatter  inv_cum_pos_nyt pos, yscale(log) mlstyle(color(gs0)) msymbol(circle) mfcolor(black) ytitle("Number of Cases") xtitle("Degree of Change")

***********************************;
***CUMULATIVE SEMI-LOG PLOT***;
***********************************;
graph set window fontface "Times New Roman"

twoway (scatter inv_cum_neg_nyt neg2, mcolor(gray) msymbol(circle) mfcolor(gray) mlcolor(gray)) (scatter inv_cum_pos_nyt pos, mcolor(black) msymbol(circle) mfcolor(black) mlcolor(black)), ytitle(Frequency) yscale(log) yscale(lcolor(black) line) ylabel(, grid glcolor(gs16)) xtitle(Degree of Change) xscale(lcolor(black) line) xlabel(, nogrid) legend(on order(1 "Negative Change Values" 2 "Positive Change Values")) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/Figs/Ch4/SEMILOG.png", replace

***********************************;
***CUMULATIVE LOG-LOG PLOT***;
***********************************;
twoway (scatter inv_cum_neg_nyt neg2, mcolor(gray) msymbol(circle) mfcolor(gray) mlcolor(gray)) (scatter inv_cum_pos_nyt pos, mcolor(black) msymbol(circle) mfcolor(black) mlcolor(black)), ytitle(Frequency) yscale(log) xscale(log) yscale(lcolor(black) line) ylabel(, grid glcolor(gs16)) xtitle(Degree of Change) xscale(lcolor(black) line) xlabel(, nogrid) legend(on order(1 "Negative Change Values" 2 "Positive Change Values")) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/Figs/Ch4/LOGLOG.png", replace

exit

***********************************;
***CUMULATIVE POS SEMI-LOG PLOT***;
***********************************;
scatter  inv_cum_pos_nyt pos, mcolor(black) yscale(log) mlstyle(color(gs0)) msymbol(circle) mfcolor(black) ytitle("Number of Cases") xtitle("Degree of Change") graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export inv_cum_pos_nyt_stories_SEMILOG.png, replace

***********************************;
***CUMULATIVE POS LOG-LOG PLOT***;
***********************************;
scatter  inv_cum_pos_nyt pos, mcolor(black) yscale(log) xscale(log) mlstyle(color(gs0)) msymbol(circle) mfcolor(black) ytitle("Number of Cases") xtitle("Degree of Change") graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export inv_cum_pos_nyt_stories_LOGLOG.png, replace


keep if neg2>0
***********************************;
***CUMULATIVE NEG SEMI-LOG PLOT***;
***********************************;
scatter  inv_cum_neg_nyt neg2, mcolor(black) yscale(log) mlstyle(color(gs0)) msymbol(circle) mfcolor(black) ytitle("Number of Cases") xtitle("Degree of Change") graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export inv_cum_neg_nyt_stories_SEMILOG.png, replace

***********************************;
***CUMULATIVE NEG LOG-LOG PLOT***;
***********************************;
scatter  inv_cum_neg_nyt neg2, mcolor(black) yscale(log) xscale(log) mlstyle(color(gs0)) msymbol(circle) mfcolor(black) ytitle("Number of Cases") xtitle("Degree of Change") graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export inv_cum_neg_nyt_stories_LOGLOG.png, replace

exit



*****************************************************************
***ADDITIONAL SYNTAX
*****************************************************************

exit
* Generate proportions
egen _freq=total(totaln)
gen prop = totaln/_freq
replace prop = .000000000000000001 if prop ==0
drop totaln _freq

* Restructure data and reduce to single row
xpose, clear varname
rename _varname old_varname
drop if old_varname=="topic"
drop old_varname

*;
#delimit cr

***********************
* Use this section for:
* MIP data
* by commenting out the #delimit command below
***********************

#delimit ;

* PAP MIP data (20 topic categories)
use /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_MIP_data/mip_1945_2007_monthly_imputed.dta, replace
drop if year<1996
drop if year>2006
foreach var of varlist imp_* {
	egen total`var' = total(`var')
	}
keep totalimp_*
keep if _n==1
egen _freq=rowtotal(totalimp_*)
foreach var of varlist totalimp_* {
	gen v`var' = `var'/_freq
	}
keep v*

* If using the MIP data, comment out the ; below
;
#delimit cr

***********************************
*   				  			  *
***********************************
* Calculate 4 measures of explosiveness  
* CHANGE NUMBER OF TOPIC CATEGORIES ACCORDINGLY
* 1. HerfindahlHirschman Index
* 2. Normalized HerfindahlHirschman Index
* 3. Inverse Shannon's H Entropy
* 4. Inverse Normalized Shannon's H Entropy 
foreach var of varlist v* {
	gen squared`var' = `var'^2
	gen lnproduct`var' = `var'*ln(`var')
	}
egen herf = rowtotal(squared*)
*gen normherf = (herf-1/27)/(1-1/27)
*gen normherf = (herf-1/20)/(1-1/20)
gen normherf = (herf-1/19)/(1-1/19)
egen total_lnproduct = rowtotal(lnproduct*)
gen entropy = -(total_lnproduct)
*gen inventropy = ln(27) - entropy
*gen inventropy = ln(20) - entropy
gen inventropy = ln(19) - entropy
*gen normentropy = (entropy/ln(27))
*gen normentropy = (entropy/ln(20))
gen normentropy = (entropy/ln(19))
gen invnormentropy = 1 - normentropy
order invnormentropy normherf inventropy herf normentropy entropy 
