cd /Users/aboydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/

clear
clear matrix
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using 5A_diversity_of_discussion.log, replace

************************************************************************************************************************
*  	Created By:		AEB                                                                                              	
*  	Creation Date:  11 May 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																							
*  	Do-file-name:   5A_diversity_of_discussion.do 		                                                                    	    
*  	Purpose:        Calculate diversity of discussion across subtopics within each topic by month                                                     	    
*  	Data Input:     2_nyt_ftpg_topics.dta								                                      	
*  	Log File:       5A_diversity_of_discussion.log    	                                                                          	
*  	Data Output:    5A_diversity_of_discussion.dta	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:               	
*
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly 
*					Questions: aboydstun@gmail.com   
************************************************************************************************************************

***********************************
* Input data and organize dataset *
***********************************

* NYT front-page data
use 3_nyt_ftpg_collapsed_by_month.dta, replace

keep month majortopic* subtopic*
	
gen	subentropy01	=	0																			
gen	numtopics01	=	0																			
egen	total01	=	rowtotal(	subtopic100	-	subtopic199	)															
foreach I of numlist	100	101	103	104	105	107	108	110	199													{
	gen	topic01_prop`I'	=	subtopic`I'/	total01																	
	recode	topic01_prop`I'	(0=.000000000000000001)																			
	replace	subentropy01	=	subentropy01	+	(	topic01_prop`I'	*	ln(	topic01_prop`I'	))											
	replace	numtopics01	=	numtopics01	+	1																
	}																					
replace	subentropy01	=	-	(	subentropy01	)																
gen	diversity01	=	(	subentropy01	/	ln(	numtopics01	))														
replace	diversity01	=	. if	diversity01	< 0.001																	
																						
																						
gen	subentropy02	=	0																			
gen	numtopics02	=	0																			
egen	total02	=	rowtotal(	subtopic200	-	subtopic299	)															
foreach I of numlist	200	201	202	204	205	206	207	208	209	299												{
	gen	topic02_prop`I'	=	subtopic`I'/	total02																	
	recode	topic02_prop`I'	(0=.000000000000000001)																			
	replace	subentropy02	=	subentropy02	+	(	topic02_prop`I'	*	ln(	topic02_prop`I'	))											
	replace	numtopics02	=	numtopics02	+	1																
	}																					
replace	subentropy02	=	-	(	subentropy02	)																
gen	diversity02	=	(	subentropy02	/	ln(	numtopics02	))														
replace	diversity02	=	. if	diversity02	< 0.001																	
																						
																						
gen	subentropy03	=	0																			
gen	numtopics03	=	0																			
egen	total03	=	rowtotal(	subtopic300	-	subtopic399	)															
foreach I of numlist	300	301	302	321	322	323	324	325	331	332	333	334	335	336	341	342	343	344	398	399		{
	gen	topic03_prop`I'	=	subtopic`I'/	total03																	
	recode	topic03_prop`I'	(0=.000000000000000001)																			
	replace	subentropy03	=	subentropy03	+	(	topic03_prop`I'	*	ln(	topic03_prop`I'	))											
	replace	numtopics03	=	numtopics03	+	1																
	}																					
replace	subentropy03	=	-	(	subentropy03	)																
gen	diversity03	=	(	subentropy03	/	ln(	numtopics03	))														
replace	diversity03	=	. if	diversity03	< 0.001																	
																						
																						
gen	subentropy04	=	0																			
gen	numtopics04	=	0																			
egen	total04	=	rowtotal(	subtopic400	-	subtopic499	)															
foreach I of numlist	400	401	402	403	404	405	498	499														{
	gen	topic04_prop`I'	=	subtopic`I'/	total04																	
	recode	topic04_prop`I'	(0=.000000000000000001)																			
	replace	subentropy04	=	subentropy04	+	(	topic04_prop`I'	*	ln(	topic04_prop`I'	))											
	replace	numtopics04	=	numtopics04	+	1																
	}																					
replace	subentropy04	=	-	(	subentropy04	)																
gen	diversity04	=	(	subentropy04	/	ln(	numtopics04	))														
replace	diversity04	=	. if	diversity04	< 0.001																	
																						
																						
gen	subentropy05	=	0																			
gen	numtopics05	=	0																			
egen	total05	=	rowtotal(	subtopic500	-	subtopic599	)															
foreach I of numlist	500	501	502	503	504	505	506	508	529	530	599											{
	gen	topic05_prop`I'	=	subtopic`I'/	total05																	
	recode	topic05_prop`I'	(0=.000000000000000001)																			
	replace	subentropy05	=	subentropy05	+	(	topic05_prop`I'	*	ln(	topic05_prop`I'	))											
	replace	numtopics05	=	numtopics05	+	1																
	}																					
replace	subentropy05	=	-	(	subentropy05	)																
gen	diversity05	=	(	subentropy05	/	ln(	numtopics05	))														
replace	diversity05	=	. if	diversity05	< 0.001																	
																						
																						
gen	subentropy06	=	0																			
gen	numtopics06	=	0																			
egen	total06	=	rowtotal(	subtopic600	-	subtopic699	)															
foreach I of numlist	600	601	602	603	604	606	607	609	698	699												{
	gen	topic06_prop`I'	=	subtopic`I'/	total06																	
	recode	topic06_prop`I'	(0=.000000000000000001)																			
	replace	subentropy06	=	subentropy06	+	(	topic06_prop`I'	*	ln(	topic06_prop`I'	))											
	replace	numtopics06	=	numtopics06	+	1																
	}																					
replace	subentropy06	=	-	(	subentropy06	)																
gen	diversity06	=	(	subentropy06	/	ln(	numtopics06	))														
replace	diversity06	=	. if	diversity06	< 0.001																	
																						
																						
gen	subentropy07	=	0																			
gen	numtopics07	=	0																			
egen	total07	=	rowtotal(	subtopic700	-	subtopic799	)															
foreach I of numlist	700	701	703	704	705	707	708	709	710	711	798	799										{
	gen	topic07_prop`I'	=	subtopic`I'/	total07																	
	recode	topic07_prop`I'	(0=.000000000000000001)																			
	replace	subentropy07	=	subentropy07	+	(	topic07_prop`I'	*	ln(	topic07_prop`I'	))											
	replace	numtopics07	=	numtopics07	+	1																
	}																					
replace	subentropy07	=	-	(	subentropy07	)																
gen	diversity07	=	(	subentropy07	/	ln(	numtopics07	))														
replace	diversity07	=	. if	diversity07	< 0.001																	
																						
																						
gen	subentropy08	=	0																			
gen	numtopics08	=	0																			
egen	total08	=	rowtotal(	subtopic800	-	subtopic899	)															
foreach I of numlist	800	801	802	803	805	806	807	898	899													{
	gen	topic08_prop`I'	=	subtopic`I'/	total08																	
	recode	topic08_prop`I'	(0=.000000000000000001)																			
	replace	subentropy08	=	subentropy08	+	(	topic08_prop`I'	*	ln(	topic08_prop`I'	))											
	replace	numtopics08	=	numtopics08	+	1																
	}																					
replace	subentropy08	=	-	(	subentropy08	)																
gen	diversity08	=	(	subentropy08	/	ln(	numtopics08	))														
replace	diversity08	=	. if	diversity08	< 0.001																	
																						
																						
gen	subentropy10	=	0																			
gen	numtopics10	=	0																			
egen	total10	=	rowtotal(	subtopic1000	-	subtopic1099	)															
foreach I of numlist	1000	1001	1002	1003	1005	1006	1007	1010	1098	1099												{
	gen	topic10_prop`I'	=	subtopic`I'/	total10																	
	recode	topic10_prop`I'	(0=.000000000000000001)																			
	replace	subentropy10	=	subentropy10	+	(	topic10_prop`I'	*	ln(	topic10_prop`I'	))											
	replace	numtopics10	=	numtopics10	+	1																
	}																					
replace	subentropy10	=	-	(	subentropy10	)																
gen	diversity10	=	(	subentropy10	/	ln(	numtopics10	))														
replace	diversity10	=	. if	diversity10	< 0.001																	
																						
																						
gen	subentropy12	=	0																			
gen	numtopics12	=	0																			
egen	total12	=	rowtotal(	subtopic1200	-	subtopic1299	)															
foreach I of numlist	1200	1201	1202	1203	1204	1205	1206	1207	1208	1209	1210	1211	1299									{
	gen	topic12_prop`I'	=	subtopic`I'/	total12																	
	recode	topic12_prop`I'	(0=.000000000000000001)																			
	replace	subentropy12	=	subentropy12	+	(	topic12_prop`I'	*	ln(	topic12_prop`I'	))											
	replace	numtopics12	=	numtopics12	+	1																
	}																					
replace	subentropy12	=	-	(	subentropy12	)																
gen	diversity12	=	(	subentropy12	/	ln(	numtopics12	))														
replace	diversity12	=	. if	diversity12	< 0.001																	
																						
																						
gen	subentropy13	=	0																			
gen	numtopics13	=	0																			
egen	total13	=	rowtotal(	subtopic1300	-	subtopic1399	)															
foreach I of numlist	1300	1301	1302	1303	1304	1305	1399															{
	gen	topic13_prop`I'	=	subtopic`I'/	total13																	
	recode	topic13_prop`I'	(0=.000000000000000001)																			
	replace	subentropy13	=	subentropy13	+	(	topic13_prop`I'	*	ln(	topic13_prop`I'	))											
	replace	numtopics13	=	numtopics13	+	1																
	}																					
replace	subentropy13	=	-	(	subentropy13	)																
gen	diversity13	=	(	subentropy13	/	ln(	numtopics13	))														
replace	diversity13	=	. if	diversity13	< 0.001																	
																						
																						
gen	subentropy14	=	0																			
gen	numtopics14	=	0																			
egen	total14	=	rowtotal(	subtopic1400	-	subtopic1499	)															
foreach I of numlist	1400	1401	1403	1404	1405	1406	1407	1408	1409	1410	1499											{
	gen	topic14_prop`I'	=	subtopic`I'/	total14																	
	recode	topic14_prop`I'	(0=.000000000000000001)																			
	replace	subentropy14	=	subentropy14	+	(	topic14_prop`I'	*	ln(	topic14_prop`I'	))											
	replace	numtopics14	=	numtopics14	+	1																
	}																					
replace	subentropy14	=	-	(	subentropy14	)																
gen	diversity14	=	(	subentropy14	/	ln(	numtopics14	))														
replace	diversity14	=	. if	diversity14	< 0.001																	
																						
																						
gen	subentropy15	=	0																			
gen	numtopics15	=	0																			
egen	total15	=	rowtotal(	subtopic1500	-	subtopic1599	)															
foreach I of numlist	1500	1501	1502	1504	1505	1507	1520	1521	1522	1523	1524	1525	1526	1599								{
	gen	topic15_prop`I'	=	subtopic`I'/	total15																	
	recode	topic15_prop`I'	(0=.000000000000000001)																			
	replace	subentropy15	=	subentropy15	+	(	topic15_prop`I'	*	ln(	topic15_prop`I'	))											
	replace	numtopics15	=	numtopics15	+	1																
	}																					
replace	subentropy15	=	-	(	subentropy15	)																
gen	diversity15	=	(	subentropy15	/	ln(	numtopics15	))														
replace	diversity15	=	. if	diversity15	< 0.001																	
																						
																						
gen	subentropy16	=	0																			
gen	numtopics16	=	0																			
egen	total16	=	rowtotal(	subtopic1600	-	subtopic1699	)															
foreach I of numlist	1600	1602	1603	1604	1605	1606	1608	1609	1610	1611	1612	1614	1615	1616	1617	1619	1620	1698	1699			{
	gen	topic16_prop`I'	=	subtopic`I'/	total16																	
	recode	topic16_prop`I'	(0=.000000000000000001)																			
	replace	subentropy16	=	subentropy16	+	(	topic16_prop`I'	*	ln(	topic16_prop`I'	))											
	replace	numtopics16	=	numtopics16	+	1																
	}																					
replace	subentropy16	=	-	(	subentropy16	)																
gen	diversity16	=	(	subentropy16	/	ln(	numtopics16	))														
replace	diversity16	=	. if	diversity16	< 0.001																	
																						
																						
gen	subentropy17	=	0																			
gen	numtopics17	=	0																			
egen	total17	=	rowtotal(	subtopic1700	-	subtopic1799	)															
foreach I of numlist	1700	1701	1704	1705	1706	1707	1708	1709	1798	1799												{
	gen	topic17_prop`I'	=	subtopic`I'/	total17																	
	recode	topic17_prop`I'	(0=.000000000000000001)																			
	replace	subentropy17	=	subentropy17	+	(	topic17_prop`I'	*	ln(	topic17_prop`I'	))											
	replace	numtopics17	=	numtopics17	+	1																
	}																					
replace	subentropy17	=	-	(	subentropy17	)																
gen	diversity17	=	(	subentropy17	/	ln(	numtopics17	))														
replace	diversity17	=	. if	diversity17	< 0.001																	
																						
																						
gen	subentropy18	=	0																			
gen	numtopics18	=	0																			
egen	total18	=	rowtotal(	subtopic1800	-	subtopic1899	)															
foreach I of numlist	1800	1802	1803	1804	1806	1807	1808	1899														{
	gen	topic18_prop`I'	=	subtopic`I'/	total18																	
	recode	topic18_prop`I'	(0=.000000000000000001)																			
	replace	subentropy18	=	subentropy18	+	(	topic18_prop`I'	*	ln(	topic18_prop`I'	))											
	replace	numtopics18	=	numtopics18	+	1																
	}																					
replace	subentropy18	=	-	(	subentropy18	)																
gen	diversity18	=	(	subentropy18	/	ln(	numtopics18	))														
replace	diversity18	=	. if	diversity18	< 0.001																	
																						
																						
gen	subentropy19	=	0																			
gen	numtopics19	=	0																			
egen	total19	=	rowtotal(	subtopic1900	-	subtopic1999	)															
foreach I of numlist	1900	1901	1902	1905	1906	1907	1908	1909	1910	1911	1912	1914	1915	1919	1920	1921	1925	1926	1927	1929	1999	{
	gen	topic19_prop`I'	=	subtopic`I'/	total19																	
	recode	topic19_prop`I'	(0=.000000000000000001)																			
	replace	subentropy19	=	subentropy19	+	(	topic19_prop`I'	*	ln(	topic19_prop`I'	))											
	replace	numtopics19	=	numtopics19	+	1																
	}																					
replace	subentropy19	=	-	(	subentropy19	)																
gen	diversity19	=	(	subentropy19	/	ln(	numtopics19	))														
replace	diversity19	=	. if	diversity19	< 0.001																	
																						
																						
gen	subentropy20	=	0																			
gen	numtopics20	=	0																			
egen	total20	=	rowtotal(	subtopic2000	-	subtopic2099	)															
foreach I of numlist	2000	2001	2002	2003	2004	2005	2006	2007	2008	2009	2010	2011	2012	2013	2014	2015	2030	2099				{
	gen	topic20_prop`I'	=	subtopic`I'/	total20																	
	recode	topic20_prop`I'	(0=.000000000000000001)																			
	replace	subentropy20	=	subentropy20	+	(	topic20_prop`I'	*	ln(	topic20_prop`I'	))											
	replace	numtopics20	=	numtopics20	+	1																
	}																					
replace	subentropy20	=	-	(	subentropy20	)																
gen	diversity20	=	(	subentropy20	/	ln(	numtopics20	))														
replace	diversity20	=	. if	diversity20	< 0.001																	
																						
																						
gen	subentropy21	=	0																			
gen	numtopics21	=	0																			
egen	total21	=	rowtotal(	subtopic2100	-	subtopic2199	)															
foreach I of numlist	2100	2101	2102	2103	2104	2105	2199															{
	gen	topic21_prop`I'	=	subtopic`I'/	total21																	
	recode	topic21_prop`I'	(0=.000000000000000001)																			
	replace	subentropy21	=	subentropy21	+	(	topic21_prop`I'	*	ln(	topic21_prop`I'	))											
	replace	numtopics21	=	numtopics21	+	1																
	}																					
replace	subentropy21	=	-	(	subentropy21	)																
gen	diversity21	=	(	subentropy21	/	ln(	numtopics21	))														
replace	diversity21	=	. if	diversity21	< 0.001																	
																						
																						
																						
*********************************
recode diversity* (.=0)																																																																																				
*********************************
																						
keep month diversity*
sort month 
																						
save 5A_diversity_of_discussion.dta, replace

