cd /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/

clear
clear matrix
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using 5_nyt_ftpg_reshape_plus_time_variables.log, replace

************************************************************************************************************************
*  	Created By:		AEB                                                                                              	
*  	Creation Date:  11 May 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																								
*  	Directory:      /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/       	       														
*  	Do-file-name:   5_nyt_ftpg_reshape.do 		                                                                    	    
*  	Purpose:        Reshape data
*					Create time control variables                                                         	    
*  	Data Input:     3_nyt_ftpg_collapsed_by_month.dta	
*					casualties_by_datemonth.dta			
*					mip_1996_2006_monthly_imputed_by_topic.dta		
*					Bills_104_to_109_1996_2006_monthly_by_topic.dta
*					hearings_1946_2008_monthly_by_topic.dta
*					execorders_1996_2003_monthly_by_topic.dta                      	
*  	Log File:       5_nyt_ftpg_reshape_plus_time_variables.log    	                                                                          	
*  	Data Output:    5_nyt_ftpg_reshape_plus_time_variables.dta											                                      	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:              	
*
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly 
*					Questions: aboydstun@gmail.com   
************************************************************************************************************************

************************************************
***RELATED ANALYSIS FOR MEDIA STORMS PROJECT***
***ADD IN CASUALTY DATA***

***Comment out this section and read in 3_nyt_ftpg_collapsed_by_month.dta file below for book analysis
#delimit ;
*
use "/Users/boydstun/Dropbox/A/_PROJECTS/Becca/data/analysis/war/controls/casualties/casualties_by_datemonth.dta", replace
sort month
gen casualties=1
collapse (sum) casualties, by(month)
sort month
merge m:1 month using 3_nyt_ftpg_collapsed_by_month.dta
sort month
drop if month>563
recode casualties(.=0)
keep month casualties majortopic* totaln
;
#delimit cr
************************************************


*data source*

use 3_nyt_ftpg_collapsed_by_month.dta, replace
keep month majortopic* totaln

reshape long majortopic, i(month) j(topic2) string
destring topic2, replace
sort topic2 month
rename majortopic stories
save modeling_data_nyt.dta, replace
clear

use "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_MIP_data/mip_1996_2006_monthly_imputed_by_topic.dta", replace
egen totalmippct = rowtotal(mippct*)
reshape long mippct, i(month) j(topic2) string
destring topic2, replace
keep topic2 month mippct totalmippct
sort topic2 month
save modeling_data_mippct.dta, replace
clear

use "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Bills_data/Bills_104_to_109_1996_2006_monthly_by_topic.dta", replace
egen totalbills = rowtotal(bills*)
reshape long bills, i(month) j(topic2) string
destring topic2, replace
keep topic2 month bills totalbills
sort topic2 month totalbills
save modeling_data_bills.dta, replace
clear

use "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_Congress_data/Hearings_data/hearings_1946_2008_monthly_by_topic.dta", replace
egen totalhearings = rowtotal(hearings*)
reshape long hearings, i(month) j(topic2) string
destring topic2, replace
keep topic2 month hearings totalhearings
sort topic2 month totalhearings
save modeling_data_hearings.dta, replace
clear

use "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_President_data/execorders_1996_2003_monthly_by_topic.dta", replace
egen totalexecorders = rowtotal(execorders*)
reshape long execorders, i(month) j(topic2) string
destring topic2, replace
keep topic2 month execorders totalexecorders
sort topic2 month totalexecorders
save modeling_data_execorders.dta, replace
clear

use 5A_diversity_of_discussion.dta, replace
reshape long diversity, i(month) j(topic2) string
destring topic2, replace
keep topic2 month diversity
sort topic2 month
save modeling_data_diversity.dta, replace
clear

use modeling_data_nyt.dta, replace

merge topic2 month using modeling_data_mippct.dta
tab _merge
drop _merge
sort topic2 month

merge topic2 month using modeling_data_bills.dta
tab _merge
drop _merge
sort topic2 month

merge topic2 month using modeling_data_hearings.dta
tab _merge
drop _merge
sort topic2 month

merge topic2 month using modeling_data_execorders.dta
tab _merge
drop _merge
sort topic2 month

merge topic2 month using modeling_data_diversity.dta
tab _merge
drop _merge
sort topic2 month

recode mippct(.=0)
recode bills(.=0)
recode totalbills(.=0)
recode hearings(.=0)
recode totalhearings(.=0)
recode execorders(.=0)
recode totalexecorders(.=0)

merge m:1 month using 5A_congestion.dta
tab _merge
drop _merge
sort topic2 month

***************************************************************************
***                 ELECTION COUNT-DOWN VARIABLES                       ***
***************************************************************************
gen election_1996=(442-month)
gen election_1998=(466-month)
gen election_2000=(490-month)
gen election_2002=(514-month)
gen election_2004=(538-month)
gen election_2006=(562-month)
gen election_2008=(586-month)

gen countdownpres=.
replace countdownpres=election_1996 if month<=442
replace countdownpres=election_2000 if (month>442 & month <=490)
replace countdownpres=election_2004 if (month>490 & month <=538)
replace countdownpres=election_2008 if month>538

gen countdowncong=.
replace countdowncong=election_1996 if month<=442
replace countdowncong=election_1998 if (month>442 & month <=466)
replace countdowncong=election_2000 if (month>466 & month <=490)
replace countdowncong=election_2002 if (month>490 & month <=514)
replace countdowncong=election_2004 if (month>514 & month <=538)
replace countdowncong=election_2006 if (month>538 & month <=562)
replace countdowncong=election_2008 if month>562

drop election_1996
drop election_1998
drop election_2000
drop election_2002
drop election_2004
drop election_2006
drop election_2008

gen electionyrpres = 0
replace electionyrpres = 1 if countdownpres <11

gen electionyrcong = 0
replace electionyrcong = 1 if countdowncong <11

gen mip_electionyrpres = mippct*electionyrpres
gen mip_electionyrcong = mippct*electionyrcong

***************************************************************************
***            		   POST-9/11 STRUCTURAL BREAK		   	            ***
***************************************************************************
gen sept11 = 0
replace sept11 = 1 if month>=476

***************************************************************************
***              DOMESTIC VS. INTERNATIONAL POLICY TOPICS               ***
***************************************************************************
gen domestic = 0
replace domestic = 1 if (topic2==1|topic2==2|topic2==3|topic2==4|topic2==5|topic2==6|topic2==7|topic2==8|topic2==10|topic2==12|topic2==13|topic2==14|topic2==15|topic2==17|topic2==20|topic2==21)

gen international = 0
replace international = 1 if (topic2==16|topic2==18|topic2==19)

tab domestic international

save 5_nyt_ftpg_reshape_plus_time_variables.dta, replace
*save 5_nyt_ftpg_reshape_plus_time_variables_for_media_storms.dta, replace

