cd /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/

clear
clear matrix
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using 6_model.log, replace

************************************************************************************************************************
*  	Created By:		AEB                                                                                              	
*  	Creation Date:  10 October 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																							
*  	Do-file-name:   6_model.do 		                                                                    	    
*  	Directory:      /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/       	       														
*  	Purpose:        Model attention across topics by month                                                     	    
*  	Data Input:     5_nyt_ftpg_reshape_plus_time_variables.dta							                                      	
*  	Log File:       5A_congestion.log    	                                                                          	
*  	Data Output:    	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	Previous File:  										  							  	
*  	NOTES:               	
*
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly 
*					Questions: aboydstun@gmail.com   
************************************************************************************************************************

use 5_nyt_ftpg_reshape_plus_time_variables.dta, replace



***********************************************************************
***					MODELING MEDIA ATTENTION						***
***********************************************************************
xtset topic2 month, monthly


*******************************
*** GENERATE LOG ODDS DEPENDENT VARIABLE
*******************************
gen propstories = stories/totaln
gen propagenda = propstories
replace propagenda = .0001 if propagenda ==0
replace propagenda = .9999 if propagenda ==1
gen logitstories = logit(propagenda)
*******************************


*******************************
*** DROP IF TOPIC>21
drop if topic>21
*******************************


*******************************
***  GENERATE PROPORTIONS 	***
*******************************
gen propbills = bills/totalbills
recode propbills (.=0)
gen prophearings = hearings/totalhearings
recode prophearings (.=0)
gen propexecorders = execorders/totalexecorders
recode propexecorders (.=0)
gen propmippct = mippct/totalmippct
recode propmippct (.=0)

order month topic2 prop*
*******************************


*******************************
*** 	KEY VARIABLES		***
*******************************
* stories = number of front-page stories on topic i in month t
* stories3avg (CREATED LOWER IN DO FILE) = average of number of stories across lags 1, 2, and 3
* propagenda = proportion of all front-page stories on topic i in month t
* logitstories = log of propagenda
* mippct = proportion of Gallup respondents citing topic i as the most important problem facing the U.S. in month t
* bills = number of Congressional bills introduced on topic i in month t
* hearings = number of Congressional hearings held on topic i in month t
* execorders = number of Presidential executive orders issued on topic i in month t
* congestion = degree of congestion on the front page in month t
*******************************


*******************************
*** 	SUMMARY STATS 		***
*******************************
sum stories logitstories L.logitstories L.bills L.execorders L.hearings L.mippct L.diversity congestion
sum logitstories L.logitstories congestion L.diversity L.mippct L.propexecorders L.prophearings 
total stories if month!=432
*******************************


*******************************
***   STATIONARITY TESTS	***
*******************************
xtunitroot fisher propstories, dfuller lags(1)
xtunitroot hadri propstories
xtunitroot fisher logitstories, dfuller lags(1)
xtunitroot hadri logitstories
*******************************




****************************************************************************************************************************
*********************************************
*** REVISED MODEL FOR BOOK REVISIONS 2012 ***
*********************************************

*** FOR DOMESTIC/INTERNATIONAL
*keep if domestic==1
*keep if international==1

* With Random Effects

*******************************
* THIS IS THE MODEL! *
sum logitstories L.logitstories L.prophearings L.propexecorders L.mippct L.diversity congestion
reg logitstories L.logitstories L.prophearings L.propexecorders L.mippct L.diversity congestion

* Ordered according to Excel file logistic_interpretation_with_figs_ALL_using_PROPORTIONS_on_rhs
sum logitstories L.logitstories congestion L.diversity L.mippct L.propexecorders L.prophearings 
reg logitstories L.logitstories congestion L.diversity L.mippct L.propexecorders L.prophearings 

*******************************

* Identical to:
xtreg logitstories L.logitstories L.prophearings L.propexecorders L.mippct L.diversity congestion, re

* Test without prior attention
reg logitstories L.logitstories L.prophearings L.propexecorders L.mippct L.diversity congestion
reg logitstories L.prophearings L.propexecorders L.mippct L.diversity congestion

*******************************
*** 	OLD MODEL 			***
*******************************
* With Random Effects
reg logitstories L.logitstories L.bills L.mippct L.diversity congestion
* Identical to:
xtreg logitstories L.logitstories L.bills L.mippct L.diversity congestion, re
****************************************************************************************************************************


*******************************
*** TEST FOR ISSUE HETEROGENEITY USING MODIFIED HAUSMAN TEST
*******************************
xtreg logitstories L.logitstories L.prophearings L.propexecorders L.mippct L.diversity congestion, fe
estimates store fixed
xtreg logitstories L.logitstories L.prophearings L.propexecorders L.mippct L.diversity congestion, re
hausman fixed .

*Regect the null that fixed effects and random effects do not differ, but likely because so much variance is being accounted for with L.logitstories
*So use RANDOM EFFECTS instead


****************************************************************************************************************************
***********************************************************************
***						MODELING MEDIA EFFECTS						***
***********************************************************************


*******************************
***   TIME SERIES MODELS	***
*******************************


*******************
*** 	MIP 	***
*******************
xtunitroot fisher mippct, dfuller lags(1)
xtunitroot fisher mippct, dfuller lags(3)
xtunitroot hadri mippct

*******************************
***   FOR CH. 9	***
*******************************
sum propstories prophearings propexecorders mippct
sum totalhearings totalexecorders totalmippct
sum L.propstories L.prophearings L.propexecorders L.mippct

reg prophearings L.propstories L.prophearings L.propexecorders L.mippct
*reg propbills L.propbills L.propstories L.propexecorders L.mippct 
reg propexecorders L.propstories L.prophearings L.propexecorders L.mippct
reg mippct L.propstories L.prophearings L.propexecorders L.mippct
reg propmippct L.propstories L.prophearings L.propexecorders L.propmippct


****************************************************************************************************************************
*********************************************
*** 		ADDITIONAL TESTS 		  ***
*********************************************

*** Random vs. fixed effects ***
xtreg logitstories L.logitstories L.prophearings L.propexecorders L.mippct L.diversity congestion, re
* For fe, signifcance disappears for hearings, execorders, diversity
xtreg logitstories L.logitstories L.prophearings L.propexecorders L.mippct L.diversity congestion, fe

*** Using bills instead of hearings ***
* Everything holds, and bills are significant, except in international topics model
reg logitstories L.logitstories L.propbills L.propexecorders L.mippct L.diversity congestion

*** Using levels on RHS ***
* all findins hold, significance increases
reg logitstories L.logitstories L.hearings L.execorders L.mippct L.diversity congestion

*** Using Proportions/Levels Instead of Log Odds ***
* For both, significance disappears on congestion but rest remains same
* Adj. R2 = 0.73 for both
reg propstories L.propstories L.prophearings L.propexecorders L.mippct L.diversity congestion
reg stories L.stories L.hearings L.execorders L.mippct L.diversity congestion

*without prior attention
reg propstories L.prophearings L.propexecorders L.mippct L.diversity congestion
reg stories L.hearings L.execorders L.mippct L.diversity congestion


*******************************
***   VAR MODELS BY TOPIC	***
*******************************

keep if topic2==1

sort month
tsset month, monthly

set more off
var stories hearings execorders mippct,lags(1/3)
vargranger

****************************************************************************************************************************




****************************************************************************************************************************



*********************************************************************************************************







