cd /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/death_penalty

clear
clear matrix
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using death_penalty_data.log, replace

*#delimit 
set more off 


************************************************************************************************************************
*  	Created By:		AEB                                                                                              	
*  	Creation Date:  13 October 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																							
*  	Do-file-name:   death_penalty_data.do 		                                                                    	    
*  	Purpose:        Compile death penalty data                                                     	    
*  	Data Input:     all_yrly_data.dta			
*					PAP_NYT_congestion.dta	
*					NEUT_yr_smoothed.dta
*					SC_dp_data.dta	                                      	
*  	Log File:       death_penalty_data.log    	                                                                          	
*  	Data Output:    death_penalty_data.dta	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:               	
*
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly, as well as the path names for the additional files below
*					Questions: aboydstun@gmail.com   
************************************************************************************************************************


***********************************************************************************************
***					NYT COVERAGE, DIVERSITY OF DISCUSSION, and EVENTS DATA					***
***********************************************************************************************

***************************************************************
***					NYT INDEX COVERAGE						***
***************************************************************

use all_yrly_data.dta, replace
* use all_qtrly_data.dta, replace

sort year

keep year d* total_art_y sentences hom

drop deathrow d1972 d1973 d1974 d1975 d1976 defendant_char deterrence defendant_and_new
*the "other" frame 99 is also excluded here
drop if year<1960
drop if year>2005

***************************************************************
***				DIVERSITY OF DISCUSSION						***
***************************************************************
***Figure out which frames were never used
foreach i of varlist d* {
	egen total`i' = total(`i')
	recode `i' (0=.) if total`i'==0
	drop total`i'
	}
	
***Drop these never-used frames
drop d501_worthit d511_prisoncheaper
drop d10_vicofficer d11_vicchild d12_vicmult d13_vicfam d14_female d19_viccharother d20_defterr d21_defmin d22_defmenthand d23_deffem d24_defparent d25_defjuv d27_defhuman d29_defcharother d30_mode d31_typecrime d32_violence d40_leg_initiative

gen	subentropy	=	0																			
gen	numtopics	=	0																			
egen	totaln	=	rowtotal(	d100	-	d719	)															
foreach i of varlist d*															{
	gen	prop`i'	=	`i'/	totaln																	
	recode	prop`i'	(0=.000000000000000001)																			
	replace	subentropy	=	subentropy	+	(	prop`i'	*	ln(	prop`i'	))											
	replace	numtopics	=	numtopics	+	1																
	}																					
replace	subentropy	=	-	(	subentropy	)																
gen	diversity	=	(	subentropy	/	ln(	numtopics	))														
replace	diversity	=	. if	diversity	< 0.001																	

*********************************
recode diversity* (.=0)																																																																																				
*********************************

***************************************************************
***				MAJOR EVENTS DUMMY VARIABLE					***
***************************************************************
generate events = 0

* MORATORIUM PERIOD:
*	Furman v. Georgia, 6/29/1972
*	Gregg v. Georgia, 7/2/1976
replace events = 1 if (year==1973 | year==1975)

keep year total_art_y diversity sentences hom events
rename total_art_y totaln
sort year
save dp_news_diversity_events.dta, replace
clear



***********************************************************************************************
***									FULL NYT CONGESTION DATA								***
***********************************************************************************************
use "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_NYT_Data/PAP_NYT_congestion.dta", replace
sort year
save congestion.dta, replace
clear



***********************************************************************************************
***										PUBLIC CONCERN DATA									***
***********************************************************************************************
* neut_dp_opinion shows the smoothed WCalc output based on the percentage of survey respondents who answered 
*"don't know" (DK) in response to a question about the death penalty, and we can think of this DK value as
*indicative of the proportion of people either ambivalent or indifferent about the issue. As public concern
*about the death penalty rises, the DK values should fall, meaning that the inverse of the DK series can serve
*as a public concern proxy

use "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/public_opinion_data/death_penalty/NEUT_yr_smoothed.dta", replace
gen opinion = 100-neut_dp_opinion
sort year
save opinion.dta, replace
clear



***********************************************************************************************
***										SUPREME COURT DATA									***
***********************************************************************************************
use "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/supreme_court_data/death_penalty/SC_dp_data.dta", replace
sort year
save supremecourt.dta, replace
clear




***********************************************************************************************
***										MERGE ALL DATA										***
***********************************************************************************************
use dp_news_diversity_events.dta, replace
sort year

merge 1:1 year using congestion.dta
tab _merge
drop _merge

sort year
merge 1:1 year using opinion.dta
tab _merge
drop _merge

sort year
merge 1:1 year using supremecourt.dta
tab _merge
drop _merge

drop if year<1960 | year>2005

save death_penalty_data.dta, replace
