cd /Users/aboydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/war

clear
clear matrix
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using war_model.log, replace

*#delimit 
set more off 


************************************************************************************************************************
*  	Created By:		AEB                                                                                              	
*  	Creation Date:  13 October 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																							
*  	Do-file-name:   war_model.do 		                                                                    	    
*  	Purpose:        Model attention to the war on terror   
* 					Run values for: 
*						Table 6.1 (see also Figure 6.1)
*						Table A.3                                                 	    
*  	Data Input:     war_data.dta							                                      	
*  	Log File:       war_model.log    	                                                                          	
*  	Data Output:    none	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:               	
*
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly 
*					Questions: aboydstun@gmail.com   
************************************************************************************************************************

set mem 400m

use war_data.dta, replace

***************************************************************
***						ARIMA ANALYSIS						***
***************************************************************

*********
* STEP 0: Look at the series over time
*********
twoway line totaln month
* FINDING: Looks like a potential downward trend at the beginning, but mostly stationary

tsset monthnumber

*********
* STEP 1: Test for stationarity (I)
*********
* Specifically, use Dickey Fuller test to determine if each series is stationary (not a unit root)
* If significant, reject the null of a unit root and assume stationarity
dfuller totaln
* FINDING: Significant dfuller test but only barely so (test statistic is barely larger than 1% critical 
* value, so look at regression using lagged value of y to see if coefficient is equal to or greater than 1
reg totaln L.totaln
* FINDING: Coefficient is only .69, so assume stationarity, since differencing with a coefficient of less
* than 1 means you'll be throwing away some of your variance
* Still, consider differencing anyway, since first part of series at least looks non-stationary
* and since approvepct below shows some signs of non-stationarity

* Larger set of dfuller specifications
dfuller totaln, lags(2) drift regress
dfuller totaln, lags(2) regress
dfuller totaln, lags(1) drift regress
dfuller totaln, lags(1) regress
dfuller totaln, drift regress
dfuller totaln, regress
* FINDING: totaln can be assumed to be stationary in all specifications above, 
* with both lag(1) and drift exhibiting significance


*********
* STEP 2a: Test for AR and MA: Visual inspection of potential AR and MA processes
*********
* Specifically, look at ACF and PACF graphs:
*	* 	An AR(p) model should show an ACF series that is a smoothly decaying function of time,
* 		either positive (for phi > 0) or alternating between positive and negative (for phi < 0)
* 		But the PACF series should be zero beyond p lags (e.g., beyond 1 lag for an AR(1) series)
* 	*	An MA(q) model should show an ACF series that is zero beyond q lags
* 		But the PACF series should be a smoothly decaying function of time, 
* 		either positive or alternating btw positive and negative
* 	*	An ARMA(p,q) model should show decays in both the ACF and PACF series

* Test for AR
ac totaln, lags(20)
* FINDING: Looks like an AR(1), maybe AR(2) process

* Test for MA
pac totaln, lags(20)
* FINDING: Looks like NOT a MA process

corrgram totaln

* REPEAT FOR DIFFERENCED DV
ac D.totaln, lags(20)
pac D.totaln, lags(20)
* FINDING: Looks like neither an AR nor an MA process

*******************************************************************
***								MODEL 
*******************************************************************

*arima totaln, arima(1,0,0) 
drop if monthnumber==65
arima totaln casualties, arima(0,0,0) 
arima totaln casualties, arima(1,0,0)

*replace totaln=. if monthnumber==65

arima totaln casualties warhearings mippct16, arima(1,0,0)
arima totaln casualties warhearings mippct16 diversity, arima(1,0,0)
arima totaln casualties warhearings mippct16 diversity congestion, arima(1,0,0)
*arima totaln casualties mippct16 diversity congestion electionyrcong, arima(1,0,0)
*arima totaln warhearings mippct16 diversity countdowncong, arima(1,0,0)

arima totaln L.casualties L.warhearings L.mippct16 L.diversity, arima(1,0,0)
*Only variables to retain significance in lagged form are: opinion, and AIC/BIC spike to 564/579 respectively
*plus contemporary casualties are only barely significant (when lagged, casualties neg and insignificant)

*SIGNIFICANT: 
***We want NON-significant white noise tests
estat ic
predict resids, residuals
gen resids_sq = resids*resids
wntestq resids, lags(20)
wntestq resids_sq, lags(20)
drop resids resids_sq
***
exit

*Calculating story counts
replace totaln=. if monthnumber==1
replace totaln=. if monthnumber==65
egen sumtotaln = total(totaln)
sum sumtotaln

sum totaln L.totaln casualties warhearings mippct16 diversity congestion 

exit

