cd /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/war

clear
clear matrix
version 11.2
capture log close
set mem 400m
set matsize 800
set more off

log using war_data.log, replace

*#delimit 
set more off 


************************************************************************************************************************
*  	Created By:		AEB                                                                                              	
*  	Creation Date:  13 October 2011                                                                                          	
*	Revised By:																											
*	Revised Date:																							
*  	Do-file-name:   war_data.do 		                                                                    	    
*  	Purpose:        Compile war data                                                     	    
*  	Data Input:     3M_war_nyt_wsj_2001_2006_collapse_month.dta
*					casualties.dta
*					CongressDates_GoodParsed.csv
*					mip_1945_2007_monthly_for_stata.csv
*					2_nyt_ftpg_topics.dta			                                      	
*  	Log File:       war_data.log    	                                                                          	
*  	Data Output:    war_data.dta	
*  	Computer Name:  Longstockings                                                                                     		  	
*  	NOTES:               	
*
*  		         	To use this do file on another computer, adjust the cd (change directory) command at the top accordingly, as well as the path names for the additional files below
*					Questions: aboydstun@gmail.com   
************************************************************************************************************************


***********************************************************************************************
***									NYT & WSJ COVERAGE DATA									***
***********************************************************************************************
use "/Users/boydstun/Dropbox/A/_PROJECTS/Becca/data/analysis/war/nyt_wsj_combined/2001_2006/3M_war_nyt_wsj_2001_2006_collapse_month.dta", replace
sort monthnumber

keep monthnumber topic*
describe

***********************************************************************************************
***								DIVERSITY OF DISCUSSION DATA								***
***********************************************************************************************
***Figure out which frames were never used
foreach i of varlist topic* {
	egen total`i' = total(`i')
	recode `i' (0=.) if total`i'==0
	drop total`i'
	}
	
***Drop these never-used frames
drop topic1013	topic1015	topic1023	topic103	topic106	topic1081	topic1089	topic1100	topic1103	topic1106	topic118	topic1196	topic1198	topic1199	topic1206	topic1209	topic1215	topic1218	topic1232	topic1234	topic1236	topic196	topic300	topic397	topic399	topic400	topic403	topic404	topic405	topic409	topic411	topic413	topic415	topic419	topic495	topic496	topic497	topic499	topic504	topic507	topic508	topic510	topic596	topic597	topic598	topic599	topic600	topic629	topic633	topic635	topic639	topic649	topic655	topic657	topic659	topic694	topic695	topic696	topic697	topic698	topic699	topic761	topic762	topic783	topic785	topic786	topic789	topic795	topic895	topic896	topic897	topic899	topic900	topic997
describe

gen	subentropy	=	0																			
gen	numtopics	=	0																			
egen	totaln	=	rowtotal(	topic100	-	topic1299	)															
foreach i of varlist topic*															{
	gen	prop`i'	=	`i'/	totaln																	
	recode	prop`i'	(0=.000000000000000001)																			
	replace	subentropy	=	subentropy	+	(	prop`i'	*	ln(	prop`i'	))											
	replace	numtopics	=	numtopics	+	1																
	}																					
replace	subentropy	=	-	(	subentropy	)																
gen	diversity	=	(	subentropy	/	ln(	numtopics	))														
replace	diversity	=	. if	diversity	< 0.001																	

*********************************
recode diversity* (.=0)																																																																																				
*********************************

keep monthnumber totaln diversity		
sort monthnumber																				
save warnews.dta, replace
clear																																							


***********************************************************************************************
***										EVENTS DATA											***
***********************************************************************************************

***************************************************************
***					1. CASUALTIES DATA						***
***************************************************************
use "/Users/boydstun/Dropbox/A/_PROJECTS/Becca/data/analysis/war/controls/casualties/casualties.dta", replace
sort monthnumber

***************************************************************
***					2. TIME VARIABLES						***
***************************************************************

gen drama = 0
replace drama = 1 if (monthnumber==1 | monthnumber==18)

gen events = 0
replace events = 1 if (monthnumber==1 | monthnumber==18)
replace events = -1 if (monthnumber==32)
sort monthnumber
save casualties_and_events.dta, replace
clear



***********************************************************************************************
***							POLICYMAKER ATTENTION DATA										***
***********************************************************************************************

#delimit;
insheet using "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/Cong_hearings_data/war/CongressDates_GoodParsed.csv";

gen warhearings = 1;

rename v1 datestring;

generate day = daily(datestring, "MDY");
format day %td;
sort day;
gen week = wofd(day);
format week %tw;
gen month = mofd(day);
format month %tm;
gen quarter = qofd(day);
format quarter %tq;
gen year = yofd(day);
format year %ty;

drop if day==.;
drop if year<2001;
drop if year>2007;

gen daynumber = day -td(11sep2001);
drop if daynumber<=0;
gen monthnumber = daynumber/30;
recode monthnumber 
(	0	/	1	=	1	)
(	1.001	/	2	=	2	)
(	2.001	/	3	=	3	)
(	3.001	/	4	=	4	)
(	4.001	/	5	=	5	)
(	5.001	/	6	=	6	)
(	6.001	/	7	=	7	)
(	7.001	/	8	=	8	)
(	8.001	/	9	=	9	)
(	9.001	/	10	=	10	)
(	10.001	/	11	=	11	)
(	11.001	/	12	=	12	)
(	12.001	/	13	=	13	)
(	13.001	/	14	=	14	)
(	14.001	/	15	=	15	)
(	15.001	/	16	=	16	)
(	16.001	/	17	=	17	)
(	17.001	/	18	=	18	)
(	18.001	/	19	=	19	)
(	19.001	/	20	=	20	)
(	20.001	/	21	=	21	)
(	21.001	/	22	=	22	)
(	22.001	/	23	=	23	)
(	23.001	/	24	=	24	)
(	24.001	/	25	=	25	)
(	25.001	/	26	=	26	)
(	26.001	/	27	=	27	)
(	27.001	/	28	=	28	)
(	28.001	/	29	=	29	)
(	29.001	/	30	=	30	)
(	30.001	/	31	=	31	)
(	31.001	/	32	=	32	)
(	32.001	/	33	=	33	)
(	33.001	/	34	=	34	)
(	34.001	/	35	=	35	)
(	35.001	/	36	=	36	)
(	36.001	/	37	=	37	)
(	37.001	/	38	=	38	)
(	38.001	/	39	=	39	)
(	39.001	/	40	=	40	)
(	40.001	/	41	=	41	)
(	41.001	/	42	=	42	)
(	42.001	/	43	=	43	)
(	43.001	/	44	=	44	)
(	44.001	/	45	=	45	)
(	45.001	/	46	=	46	)
(	46.001	/	47	=	47	)
(	47.001	/	48	=	48	)
(	48.001	/	49	=	49	)
(	49.001	/	50	=	50	)
(	50.001	/	51	=	51	)
(	51.001	/	52	=	52	)
(	52.001	/	53	=	53	)
(	53.001	/	54	=	54	)
(	54.001	/	55	=	55	)
(	55.001	/	56	=	56	)
(	56.001	/	57	=	57	)
(	57.001	/	58	=	58	)
(	58.001	/	59	=	59	)
(	59.001	/	60	=	60	)
(	60.001	/	61	=	61	)
(	61.001	/	62	=	62	)
(	62.001	/	63	=	63	)
(	63.001	/	64	=	64	)
(	64.001	/	65	=	65	)
(	65.001	/	66	=	66	)
(	66.001	/	67	=	67	)
(	67.001	/	68	=	68	)
(	68.001	/	69	=	69	)
(	69.001	/	70	=	70	);

drop if monthnumber>65;

sort monthnumber;

collapse (sum) warhearings, by (monthnumber);
sort monthnumber;

recode warhearings (.=0);

save warhearings.dta, replace;
clear;

***********************************************************************************************
***								PUBLIC CONCERN DATA											***
***********************************************************************************************
*use "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_MIP_data/mip_1996_2007_monthly_imputed_by_topic.dta", replace	
*drop if month<501
*gen monthnumber = _n

***Same code from /Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_MIP_data/mip_1945_2007_monthly_imputed.do

#delimit;
insheet using "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/data/PAP_MIP_data/mip_1945_2007_monthly_for_stata.csv";
drop v15;

drop if irrelevant==1;

rename dateofsourcedocument datestring;

rename year yearstring;
generate day = daily(datestring, "MDY");
format day %td;
sort day;
gen week = wofd(day);
format week %tw;
gen month = mofd(day);
format month %tm;
gen quarter = qofd(day);
format quarter %tq;
gen year = yofd(day);
format year %ty;

drop if day==.;
drop if year<2001;
drop if year>2007;

gen daynumber = day -td(11sep2001);
drop if daynumber<=0;
gen monthnumber = daynumber/30;
recode monthnumber 
(	0	/	1	=	1	)
(	1.001	/	2	=	2	)
(	2.001	/	3	=	3	)
(	3.001	/	4	=	4	)
(	4.001	/	5	=	5	)
(	5.001	/	6	=	6	)
(	6.001	/	7	=	7	)
(	7.001	/	8	=	8	)
(	8.001	/	9	=	9	)
(	9.001	/	10	=	10	)
(	10.001	/	11	=	11	)
(	11.001	/	12	=	12	)
(	12.001	/	13	=	13	)
(	13.001	/	14	=	14	)
(	14.001	/	15	=	15	)
(	15.001	/	16	=	16	)
(	16.001	/	17	=	17	)
(	17.001	/	18	=	18	)
(	18.001	/	19	=	19	)
(	19.001	/	20	=	20	)
(	20.001	/	21	=	21	)
(	21.001	/	22	=	22	)
(	22.001	/	23	=	23	)
(	23.001	/	24	=	24	)
(	24.001	/	25	=	25	)
(	25.001	/	26	=	26	)
(	26.001	/	27	=	27	)
(	27.001	/	28	=	28	)
(	28.001	/	29	=	29	)
(	29.001	/	30	=	30	)
(	30.001	/	31	=	31	)
(	31.001	/	32	=	32	)
(	32.001	/	33	=	33	)
(	33.001	/	34	=	34	)
(	34.001	/	35	=	35	)
(	35.001	/	36	=	36	)
(	36.001	/	37	=	37	)
(	37.001	/	38	=	38	)
(	38.001	/	39	=	39	)
(	39.001	/	40	=	40	)
(	40.001	/	41	=	41	)
(	41.001	/	42	=	42	)
(	42.001	/	43	=	43	)
(	43.001	/	44	=	44	)
(	44.001	/	45	=	45	)
(	45.001	/	46	=	46	)
(	46.001	/	47	=	47	)
(	47.001	/	48	=	48	)
(	48.001	/	49	=	49	)
(	49.001	/	50	=	50	)
(	50.001	/	51	=	51	)
(	51.001	/	52	=	52	)
(	52.001	/	53	=	53	)
(	53.001	/	54	=	54	)
(	54.001	/	55	=	55	)
(	55.001	/	56	=	56	)
(	56.001	/	57	=	57	)
(	57.001	/	58	=	58	)
(	58.001	/	59	=	59	)
(	59.001	/	60	=	60	)
(	60.001	/	61	=	61	)
(	61.001	/	62	=	62	)
(	62.001	/	63	=	63	)
(	63.001	/	64	=	64	)
(	64.001	/	65	=	65	)
(	65.001	/	66	=	66	)
(	66.001	/	67	=	67	)
(	67.001	/	68	=	68	)
(	68.001	/	69	=	69	)
(	69.001	/	70	=	70	);

drop if monthnumber>65;

sort monthnumber;

collapse (mean) p1 p2 p3 p4 p5 p6 p7 p8 p10 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p25, by (monthnumber);
sort monthnumber;

merge m:1 monthnumber using warnews.dta;
tab _merge;
drop _merge;
drop totaln diversity;
sort monthnumber;

gen	raw_p1	=	p1	;
gen	raw_p2	=	p2	;
gen	raw_p3	=	p3	;
gen	raw_p4	=	p4	;
gen	raw_p5	=	p5	;
gen	raw_p6	=	p6	;
gen	raw_p7	=	p7	;
gen	raw_p8	=	p8	;
gen	raw_p10	=	p10	;
gen	raw_p12	=	p12	;
gen	raw_p13	=	p13	;
gen	raw_p14	=	p14	;
gen	raw_p15	=	p15	;
gen	raw_p16	=	p16	;
gen	raw_p17	=	p17	;
gen	raw_p18	=	p18	;
gen	raw_p19	=	p19	;
gen	raw_p20	=	p20	;
gen	raw_p21	=	p21	;
gen	raw_p25	=	p25	;

rename	p1	imp_p1	;
rename	p2	imp_p2	;
rename	p3	imp_p3	;
rename	p4	imp_p4	;
rename	p5	imp_p5	;
rename	p6	imp_p6	;
rename	p7	imp_p7	;
rename	p8	imp_p8	;
rename	p10	imp_p10	;
rename	p12	imp_p12	;
rename	p13	imp_p13	;
rename	p14	imp_p14	;
rename	p15	imp_p15	;
rename	p16	imp_p16	;
rename	p17	imp_p17	;
rename	p18	imp_p18	;
rename	p19	imp_p19	;
rename	p20	imp_p20	;
rename	p21	imp_p21	;
rename	p25	imp_p25	;

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};

foreach x of varlist imp_p* {;

replace `x'=	`x'[_n-1]+((	`x'[_n+1]	-	`x'[_n-1])/	2	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]!=.  																																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+2]	-	`x'[_n-1])/	3	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]!=. 																																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+3]	-	`x'[_n-1])/	4	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]!=.																																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+4]	-	`x'[_n-1])/	5	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]!=.																																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+5]	-	`x'[_n-1])/	6	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]!=.																																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+6]	-	`x'[_n-1])/	7	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]!=.																																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+7]	-	`x'[_n-1])/	8	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]!=.																																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+8]	-	`x'[_n-1])/	9	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]!=.																																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+9]	-	`x'[_n-1])/	10	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]!=.																																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+10]	-	`x'[_n-1])/	11	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]!=.																																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+11]	-	`x'[_n-1])/	12	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]!=.																																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+12]	-	`x'[_n-1])/	13	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]!=.																																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+13]	-	`x'[_n-1])/	14	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]!=.																																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+14]	-	`x'[_n-1])/	15	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]!=.																																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+15]	-	`x'[_n-1])/	16	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]!=.																																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+16]	-	`x'[_n-1])/	17	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]!=.																																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+17]	-	`x'[_n-1])/	18	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]!=.																																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+18]	-	`x'[_n-1])/	19	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]!=.																																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+19]	-	`x'[_n-1])/	20	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]!=.																																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+20]	-	`x'[_n-1])/	21	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]!=.																																			);
replace `x'=	`x'[_n-1]+((	`x'[_n+21]	-	`x'[_n-1])/	22	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]!=.																																	);
replace `x'=	`x'[_n-1]+((	`x'[_n+22]	-	`x'[_n-1])/	23	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]!=.																															);
replace `x'=	`x'[_n-1]+((	`x'[_n+23]	-	`x'[_n-1])/	24	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]!=.																													);
replace `x'=	`x'[_n-1]+((	`x'[_n+24]	-	`x'[_n-1])/	25	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]!=.																											);
replace `x'=	`x'[_n-1]+((	`x'[_n+25]	-	`x'[_n-1])/	26	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]!=.																									);
replace `x'=	`x'[_n-1]+((	`x'[_n+26]	-	`x'[_n-1])/	27	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]!=.																							);
replace `x'=	`x'[_n-1]+((	`x'[_n+27]	-	`x'[_n-1])/	28	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]!=.																					);
replace `x'=	`x'[_n-1]+((	`x'[_n+28]	-	`x'[_n-1])/	29	) if (	`x'==. &	`x'[_n-1]!=. & 	`x'[_n+1]==. 	&	`x'[_n+2]==. 	&	`x'[_n+3]==.	&	`x'[_n+4]==.	&	`x'[_n+5]==.	&	`x'[_n+6]==.	&	`x'[_n+7]==.	&	`x'[_n+8]==.	&	`x'[_n+9]==.	&	`x'[_n+10]==.	&	`x'[_n+11]==.	&	`x'[_n+12]==.	&	`x'[_n+13]==.	&	`x'[_n+14]==.	&	`x'[_n+15]==.	&	`x'[_n+16]==.	&	`x'[_n+17]==.	&	`x'[_n+18]==.	&	`x'[_n+19]==.	&	`x'[_n+20]==.	&	`x'[_n+21]==.	&	`x'[_n+22]==.	&	`x'[_n+23]==.	&	`x'[_n+24]==.	&	`x'[_n+25]==.	&	`x'[_n+26]==.	&	`x'[_n+27]==.	&	`x'[_n+28]!=.																			);

};


#delimit cr
drop raw*

drop imp_p25

*Leaving out topic 25 "other/DK"
foreach i of numlist 1 2 3 4 5 6 7 8 10 12 13 14 15 16 17 18 19 20 21 {
	rename imp_p`i' mippct`i'
	}

keep monthnumber mippct16
sort monthnumber
save mip.dta, replace



***********************************************************************************************
***									AGENDA CONGESTION DATA									***
***********************************************************************************************
use "/Users/boydstun/Dropbox/A/_PROJECTS/nyt/book/analysis/2_nyt_ftpg_topics.dta", replace

keep day majortopic*

#delimit ;

gen daynumber = day -td(11sep2001);
drop if daynumber<=0;
gen monthnumber = daynumber/30;
recode monthnumber 
(	0	/	1	=	1	)
(	1.001	/	2	=	2	)
(	2.001	/	3	=	3	)
(	3.001	/	4	=	4	)
(	4.001	/	5	=	5	)
(	5.001	/	6	=	6	)
(	6.001	/	7	=	7	)
(	7.001	/	8	=	8	)
(	8.001	/	9	=	9	)
(	9.001	/	10	=	10	)
(	10.001	/	11	=	11	)
(	11.001	/	12	=	12	)
(	12.001	/	13	=	13	)
(	13.001	/	14	=	14	)
(	14.001	/	15	=	15	)
(	15.001	/	16	=	16	)
(	16.001	/	17	=	17	)
(	17.001	/	18	=	18	)
(	18.001	/	19	=	19	)
(	19.001	/	20	=	20	)
(	20.001	/	21	=	21	)
(	21.001	/	22	=	22	)
(	22.001	/	23	=	23	)
(	23.001	/	24	=	24	)
(	24.001	/	25	=	25	)
(	25.001	/	26	=	26	)
(	26.001	/	27	=	27	)
(	27.001	/	28	=	28	)
(	28.001	/	29	=	29	)
(	29.001	/	30	=	30	)
(	30.001	/	31	=	31	)
(	31.001	/	32	=	32	)
(	32.001	/	33	=	33	)
(	33.001	/	34	=	34	)
(	34.001	/	35	=	35	)
(	35.001	/	36	=	36	)
(	36.001	/	37	=	37	)
(	37.001	/	38	=	38	)
(	38.001	/	39	=	39	)
(	39.001	/	40	=	40	)
(	40.001	/	41	=	41	)
(	41.001	/	42	=	42	)
(	42.001	/	43	=	43	)
(	43.001	/	44	=	44	)
(	44.001	/	45	=	45	)
(	45.001	/	46	=	46	)
(	46.001	/	47	=	47	)
(	47.001	/	48	=	48	)
(	48.001	/	49	=	49	)
(	49.001	/	50	=	50	)
(	50.001	/	51	=	51	)
(	51.001	/	52	=	52	)
(	52.001	/	53	=	53	)
(	53.001	/	54	=	54	)
(	54.001	/	55	=	55	)
(	55.001	/	56	=	56	)
(	56.001	/	57	=	57	)
(	57.001	/	58	=	58	)
(	58.001	/	59	=	59	)
(	59.001	/	60	=	60	)
(	60.001	/	61	=	61	)
(	61.001	/	62	=	62	)
(	62.001	/	63	=	63	)
(	63.001	/	64	=	64	)
(	64.001	/	65	=	65	)
(	65.001	/	66	=	66	)
(	66.001	/	67	=	67	)
(	67.001	/	68	=	68	)
(	68.001	/	69	=	69	)
(	69.001	/	70	=	70	);

#delimit cr

gen totaln = 1

collapse(sum) totaln majortopic*, by(monthnumber)

***SAME CODE FROM 5A_congestion.do FILE
gen	subentropy	=	0																			
gen	numtopics	=	0																			
egen	total	=	rowtotal(majortopic1	-	majortopic99)															
*foreach i of numlist	1 2 3 4 5 6 7 8 10 12 13 14 15 16 17 18 19 20 21	{
foreach i of numlist	1 2 3 4 5 6 7 8 10 12 13 14 15 16 17 18 19 20 21 24 26 27 28 29 30 31 99	{
	gen	prop`i'	=	majortopic`i'/total																	
	recode	prop`i'	(0=.000000000000000001)																			
	replace	subentropy	=	subentropy	+	(	prop`i'	*	ln(	prop`i'	))											
	replace	numtopics	=	numtopics	+	1																
	}																					
replace	subentropy	=	-	(	subentropy	)																
gen	diversity	=	(	subentropy	/	ln(	numtopics	))		
gen congestion = 1 - diversity												
																																																																																																																										
keep monthnumber congestion*
sort monthnumber
save congestion.dta, replace
clear



***********************************************************************************************
***										MERGE ALL DATA										***
***********************************************************************************************
use warnews.dta, replace
sort monthnumber

merge 1:1 monthnumber using casualties_and_events.dta
tab _merge
recode casualties(.=0)
recode drama (.=0)
recode events (.=0)
drop _merge

sort monthnumber
merge 1:1 monthnumber using warhearings.dta
recode warhearings (.=0)
recode warhearings (0=.) if monthnumber==65
tab _merge
drop _merge

sort monthnumber
merge 1:1 monthnumber using mip.dta
tab _merge
drop _merge

sort monthnumber
merge 1:1 monthnumber using congestion.dta
tab _merge
drop _merge

***************************************************************************
***                 ELECTION COUNT-DOWN VARIABLES                       ***
***************************************************************************
gen election_2002=(14-monthnumber)
gen election_2004=(38-monthnumber)
gen election_2006=(62-monthnumber)
gen election_2008=(86-monthnumber)

gen countdowncong=.
replace countdowncong=election_2002 if monthnumber <=14
replace countdowncong=election_2004 if (monthnumber >14 & monthnumber <=38)
replace countdowncong=election_2006 if (monthnumber >38 & monthnumber <=62)
replace countdowncong=election_2008 if monthnumber >62

gen countdownpres=.
replace countdownpres=election_2004 if monthnumber <=38
replace countdownpres=election_2008 if monthnumber >38

drop election_2002
drop election_2004
drop election_2006
drop election_2008

gen electionyrpres = 0
replace electionyrpres = 1 if countdownpres <11

gen electionyrcong = 0
replace electionyrcong = 1 if countdowncong <11

save war_data.dta, replace
exit






